from .aila_casedocs_retrieval import AILACasedocs
from .aila_statutes_retrieval import AILAStatutes
from .alpha_nli_retrieval import AlphaNLI
from .arc_challenge_retrieval import ARCChallenge
from .argu_ana_retrieval import ArguAna
from .audio_set_strong import AudioSetStrongA2TRetrieval, AudioSetStrongT2ARetrieval
from .bar_exam_qa_retrieval import BarExamQARetrieval
from .bill_sum_ca_retrieval import BillSumCARetrieval
from .bill_sum_us_retrieval import BillSumUSRetrieval
from .birco_argu_ana_reranking import BIRCOArguAnaReranking
from .birco_clinical_trial_reranking import BIRCOClinicalTrialReranking
from .birco_doris_mae_reranking import BIRCODorisMaeReranking
from .birco_relic_reranking import BIRCORelicReranking
from .birco_whats_that_book_reranking import BIRCOWhatsThatBookReranking
from .blink_it2i_retrieval import BLINKIT2IRetrieval
from .blink_it2t_retrieval import BLINKIT2TRetrieval
from .bright_retrieval import BrightLongRetrieval, BrightRetrieval
from .bright_v1_1_retrieval import (
    BrightAopsRetrieval,
    BrightBiologyLongRetrieval,
    BrightBiologyRetrieval,
    BrightEarthScienceLongRetrieval,
    BrightEarthScienceRetrieval,
    BrightEconomicsLongRetrieval,
    BrightEconomicsRetrieval,
    BrightLeetcodeRetrieval,
    BrightPonyLongRetrieval,
    BrightPonyRetrieval,
    BrightPsychologyLongRetrieval,
    BrightPsychologyRetrieval,
    BrightRoboticsLongRetrieval,
    BrightRoboticsRetrieval,
    BrightStackoverflowLongRetrieval,
    BrightStackoverflowRetrieval,
    BrightSustainableLivingLongRetrieval,
    BrightSustainableLivingRetrieval,
    BrightTheoremQAQuestionsRetrieval,
    BrightTheoremQATheoremsRetrieval,
)
from .built_bench_retrieval import BuiltBenchRetrieval
from .chat_doctor_retrieval import ChatDoctorRetrieval
from .chem_hotpot_qa_retrieval import ChemHotpotQARetrieval
from .chem_nq_retrieval import ChemNQRetrieval
from .chemrxiv import ChemRxivRetrieval
from .cirr_it2i_retrieval import CIRRIT2IRetrieval
from .climate_fever_retrieval import (
    ClimateFEVER,
    ClimateFEVERHardNegatives,
    ClimateFEVERHardNegativesV2,
    ClimateFEVERRetrievalv2,
)
from .clotho import ClothoA2TRetrieval, ClothoT2ARetrieval
from .cmu_arctic import CMUArcticA2TRetrieval, CMUArcticT2ARetrieval
from .cqa_dupstack_android_retrieval import CQADupstackAndroidRetrieval
from .cqa_dupstack_english_retrieval import CQADupstackEnglishRetrieval
from .cqa_dupstack_gaming_retrieval import CQADupstackGamingRetrieval
from .cqa_dupstack_gis_retrieval import CQADupstackGisRetrieval
from .cqa_dupstack_mathematica_retrieval import CQADupstackMathematicaRetrieval
from .cqa_dupstack_physics_retrieval import CQADupstackPhysicsRetrieval
from .cqa_dupstack_programmers_retrieval import CQADupstackProgrammersRetrieval
from .cqa_dupstack_stats_retrieval import CQADupstackStatsRetrieval
from .cqa_dupstack_tex_retrieval import CQADupstackTexRetrieval
from .cqa_dupstack_unix_retrieval import CQADupstackUnixRetrieval
from .cqa_dupstack_webmasters_retrieval import CQADupstackWebmastersRetrieval
from .cqa_dupstack_wordpress_retrieval import CQADupstackWordpressRetrieval
from .cub200_i2i_retrieval import CUB200I2I
from .dapfam_patent_retrieval import (
    DAPFAMAllTitlAbsClmToFullTextRetrieval,
    DAPFAMAllTitlAbsClmToTitlAbsClmRetrieval,
    DAPFAMAllTitlAbsClmToTitlAbsRetrieval,
    DAPFAMAllTitlAbsToFullTextRetrieval,
    DAPFAMAllTitlAbsToTitlAbsClmRetrieval,
    DAPFAMAllTitlAbsToTitlAbsRetrieval,
    DAPFAMInTitlAbsClmToFullTextRetrieval,
    DAPFAMInTitlAbsClmToTitlAbsClmRetrieval,
    DAPFAMInTitlAbsClmToTitlAbsRetrieval,
    DAPFAMInTitlAbsToFullTextRetrieval,
    DAPFAMInTitlAbsToTitlAbsClmRetrieval,
    DAPFAMInTitlAbsToTitlAbsRetrieval,
    DAPFAMOutTitlAbsClmToFullTextRetrieval,
    DAPFAMOutTitlAbsClmToTitlAbsClmRetrieval,
    DAPFAMOutTitlAbsClmToTitlAbsRetrieval,
    DAPFAMOutTitlAbsToFullTextRetrieval,
    DAPFAMOutTitlAbsToTitlAbsClmRetrieval,
    DAPFAMOutTitlAbsToTitlAbsRetrieval,
)
from .dbpedia_retrieval import DBPedia, DBPediaHardNegatives, DBPediaHardNegativesV2
from .edis_t2it_retrieval import EDIST2ITRetrieval
from .emo_vdb import EmoVDBA2TRetrieval, EmoVDBT2ARetrieval
from .encyclopedia_vqa_it2it_retrieval import EncyclopediaVQAIT2ITRetrieval
from .english_finance1_retrieval import EnglishFinance1Retrieval
from .english_finance2_retrieval import EnglishFinance2Retrieval
from .english_finance3_retrieval import EnglishFinance3Retrieval
from .english_finance4_retrieval import EnglishFinance4Retrieval
from .english_healthcare1_retrieval import EnglishHealthcare1Retrieval
from .faith_dial_retrieval import FaithDialRetrieval
from .fashion200k_i2t_retrieval import Fashion200kI2TRetrieval
from .fashion200k_t2i_retrieval import Fashion200kT2IRetrieval
from .fashion_iq_it2i_retrieval import FashionIQIT2IRetrieval
from .feedback_qa_retrieval import FeedbackQARetrieval
from .fever_retrieval import FEVER, FEVERHardNegatives, FEVERHardNegativesV2
from .fi_qa2018_retrieval import FiQA2018
from .fin_qa_retrieval import FinQARetrieval
from .finance_bench_retrieval import FinanceBenchRetrieval
from .flickr30k_i2t_retrieval import Flickr30kI2TRetrieval
from .flickr30k_t2i_retrieval import Flickr30kT2IRetrieval
from .forb_i2i_retrieval import FORBI2I
from .giga_speech import GigaSpeechA2TRetrieval, GigaSpeechT2ARetrieval
from .gl_dv2_i2i_retrieval import GLDv2I2IRetrieval
from .gl_dv2_i2t_retrieval import GLDv2I2TRetrieval
from .gov_report_retrieval import GovReportRetrieval
from .hagrid_retrieval import HagridRetrieval
from .hateful_memes_i2t_retrieval import HatefulMemesI2TRetrieval
from .hateful_memes_t2i_retrieval import HatefulMemesT2IRetrieval
from .hc3_finance_retrieval import HC3FinanceRetrieval
from .hella_swag_retrieval import HellaSwag
from .hi_fi_tts import HiFiTTSA2TRetrieval, HiFiTTST2ARetrieval
from .hotpot_qa_retrieval import (
    HotpotQA,
    HotpotQAHardNegatives,
    HotpotQAHardNegativesV2,
)
from .image_co_de_t2i_retrieval import ImageCoDeT2IRetrieval
from .info_seek_it2it_retrieval import InfoSeekIT2ITRetrieval
from .info_seek_it2t_retrieval import InfoSeekIT2TRetrieval
from .jl_corpus import JLCorpusA2TRetrieval, JLCorpusT2ARetrieval
from .lass import LASSA2TRetrieval, LASST2ARetrieval
from .legal_bench_consumer_contracts_qa_retrieval import LegalBenchConsumerContractsQA
from .legal_bench_corporate_lobbying_retrieval import LegalBenchCorporateLobbying
from .legal_summarization_retrieval import LegalSummarization
from .lemb_narrative_qa_retrieval import LEMBNarrativeQARetrieval
from .lemb_needle_retrieval import LEMBNeedleRetrieval
from .lemb_passkey_retrieval import LEMBPasskeyRetrieval
from .lemb_summ_screen_fd_retrieval import LEMBSummScreenFDRetrieval
from .lemb_wikim_qa_retrieval import LEMBWikimQARetrieval
from .lembqm_sum_retrieval import LEMBQMSumRetrieval
from .libri_tts import LibriTTSA2TRetrieval, LibriTTST2ARetrieval
from .limit_retrieval import LIMITRetrieval, LIMITSmallRetrieval
from .lit_search_retrieval import LitSearchRetrieval
from .llava_it2t_retrieval import LLaVAIT2TRetrieval
from .lotte_retrieval import LoTTERetrieval
from .macs import MACSA2TRetrieval, MACST2ARetrieval
from .medical_qa_retrieval import MedicalQARetrieval
from .memotion_i2t_retrieval import MemotionI2TRetrieval
from .memotion_t2i_retrieval import MemotionT2IRetrieval
from .met_i2i_retrieval import METI2IRetrieval
from .ml_questions import MLQuestionsRetrieval
from .mscoco_i2t_retrieval import MSCOCOI2TRetrieval
from .mscoco_t2i_retrieval import MSCOCOT2IRetrieval
from .msmarc_ov2_retrieval import MSMARCOv2
from .msmarco_retrieval import MSMARCO, MSMARCOHardNegatives
from .nano_argu_ana_retrieval import NanoArguAnaRetrieval
from .nano_climate_fever_retrieval import NanoClimateFeverRetrieval
from .nano_db_pedia_retrieval import NanoDBPediaRetrieval
from .nano_fever_retrieval import NanoFEVERRetrieval
from .nano_fi_qa2018_retrieval import NanoFiQA2018Retrieval
from .nano_hotpot_qa_retrieval import NanoHotpotQARetrieval
from .nano_msmarco_retrieval import NanoMSMARCORetrieval
from .nano_nf_corpus_retrieval import NanoNFCorpusRetrieval
from .nano_nq_retrieval import NanoNQRetrieval
from .nano_quora_retrieval import NanoQuoraRetrieval
from .nano_sci_fact_retrieval import NanoSciFactRetrieval
from .nano_scidocs_retrieval import NanoSCIDOCSRetrieval
from .nano_touche2020_retrieval import NanoTouche2020Retrieval
from .narrative_qa_retrieval import NarrativeQARetrieval
from .nf_corpus_retrieval import NFCorpus
from .nights_i2i_retrieval import NIGHTSI2IRetrieval
from .nq_retrieval import NQ, NQHardNegatives
from .okvqa_it2t_retrieval import OKVQAIT2TRetrieval
from .oven_it2it_retrieval import OVENIT2ITRetrieval
from .oven_it2t_retrieval import OVENIT2TRetrieval
from .piqa_retrieval import PIQA
from .quail_retrieval import Quail
from .quora_retrieval import (
    QuoraRetrieval,
    QuoraRetrievalHardNegatives,
    QuoraRetrievalHardNegativesV2,
)
from .r2_med_retrieval import (
    R2MEDBioinformaticsRetrieval,
    R2MEDBiologyRetrieval,
    R2MEDIIYiClinicalRetrieval,
    R2MEDMedicalSciencesRetrieval,
    R2MEDMedQADiagRetrieval,
    R2MEDMedXpertQAExamRetrieval,
    R2MEDPMCClinicalRetrieval,
    R2MEDPMCTreatmentRetrieval,
)
from .r_oxford_i2i_retrieval import (
    ROxfordEasyI2IRetrieval,
    ROxfordHardI2IRetrieval,
    ROxfordMediumI2IRetrieval,
)
from .r_paris_i2i_retrieval import (
    RParisEasyI2IRetrieval,
    RParisHardI2IRetrieval,
    RParisMediumI2IRetrieval,
)
from .ra_rb_code_retrieval import RARbCode
from .ra_rb_math_retrieval import RARbMath
from .re_mu_q_it2t_retrieval import ReMuQIT2TRetrieval
from .rp2k_i2i_retrieval import RP2kI2IRetrieval
from .sci_fact_retrieval import SciFact
from .sci_mmir_i2t_retrieval import SciMMIRI2TRetrieval
from .sci_mmir_t2i_retrieval import SciMMIRT2IRetrieval
from .scidocs_retrieval import SCIDOCS
from .siqa_retrieval import SIQA
from .sketchy_i2i_retrieval import SketchyI2IRetrieval
from .sop_i2i_retrieval import SOPI2IRetrieval
from .spart_qa_retrieval import SpartQA
from .spoken_s_qu_ad import SpokenSQuADT2ARetrieval
from .stanford_cars_i2i_retrieval import StanfordCarsI2I
from .temp_reason_l1_retrieval import TempReasonL1
from .temp_reason_l2_context_retrieval import TempReasonL2Context
from .temp_reason_l2_fact_retrieval import TempReasonL2Fact
from .temp_reason_l2_pure_retrieval import TempReasonL2Pure
from .temp_reason_l3_context_retrieval import TempReasonL3Context
from .temp_reason_l3_fact_retrieval import TempReasonL3Fact
from .temp_reason_l3_pure_retrieval import TempReasonL3Pure
from .topi_ocqa_retrieval import TopiOCQARetrieval, TopiOCQARetrievalHardNegatives
from .touche2020_retrieval import Touche2020, Touche2020v3Retrieval
from .treccovid_retrieval import TRECCOVID
from .trecdl_retrieval import TRECDL2019, TRECDL2020
from .tu_berlin_t2i_retrieval import TUBerlinT2IRetrieval
from .vidore_bench_retrieval import (
    VidoreArxivQARetrieval,
    VidoreDocVQARetrieval,
    VidoreInfoVQARetrieval,
    VidoreShiftProjectRetrieval,
    VidoreSyntheticDocQAAIRetrieval,
    VidoreSyntheticDocQAEnergyRetrieval,
    VidoreSyntheticDocQAGovernmentReportsRetrieval,
    VidoreSyntheticDocQAHealthcareIndustryRetrieval,
    VidoreTabfquadRetrieval,
    VidoreTatdqaRetrieval,
)
from .visrag_ret_arxiv_qa_retrieval import VisRAGRetArxivQA
from .visrag_ret_chart_qa_retrieval import VisRAGRetChartQA
from .visrag_ret_info_vqa_retrieval import VisRAGRetInfoVQA
from .visrag_ret_mp_docvqa_retrieval import VisRAGRetMPDocVQA
from .visrag_ret_plot_qa_retrieval import VisRAGRetPlotQA
from .visrag_ret_slide_vqa_retrieval import VisRAGRetSlideVQA
from .visual_news_i2t_retrieval import VisualNewsI2TRetrieval
from .visual_news_t2i_retrieval import VisualNewsT2IRetrieval
from .viz_wiz_it2t_retrieval import VizWizIT2TRetrieval
from .vqa2_it2t_retrieval import VQA2IT2TRetrieval
from .web_qa_t2it_retrieval import WebQAT2ITRetrieval
from .web_qa_t2t_retrieval import WebQAT2TRetrieval
from .wino_grande_retrieval import WinoGrande

__all__ = [
    "CUB200I2I",
    "FEVER",
    "FORBI2I",
    "MSMARCO",
    "NQ",
    "PIQA",
    "SCIDOCS",
    "SIQA",
    "TRECCOVID",
    "TRECDL2019",
    "TRECDL2020",
    "AILACasedocs",
    "AILAStatutes",
    "ARCChallenge",
    "AlphaNLI",
    "ArguAna",
    "AudioSetStrongA2TRetrieval",
    "AudioSetStrongT2ARetrieval",
    "BIRCOArguAnaReranking",
    "BIRCOClinicalTrialReranking",
    "BIRCODorisMaeReranking",
    "BIRCORelicReranking",
    "BIRCOWhatsThatBookReranking",
    "BLINKIT2IRetrieval",
    "BLINKIT2TRetrieval",
    "BarExamQARetrieval",
    "BillSumCARetrieval",
    "BillSumUSRetrieval",
    "BrightAopsRetrieval",
    "BrightBiologyLongRetrieval",
    "BrightBiologyRetrieval",
    "BrightEarthScienceLongRetrieval",
    "BrightEarthScienceRetrieval",
    "BrightEconomicsLongRetrieval",
    "BrightEconomicsRetrieval",
    "BrightLeetcodeRetrieval",
    "BrightLongRetrieval",
    "BrightPonyLongRetrieval",
    "BrightPonyRetrieval",
    "BrightPsychologyLongRetrieval",
    "BrightPsychologyRetrieval",
    "BrightRetrieval",
    "BrightRoboticsLongRetrieval",
    "BrightRoboticsRetrieval",
    "BrightStackoverflowLongRetrieval",
    "BrightStackoverflowRetrieval",
    "BrightSustainableLivingLongRetrieval",
    "BrightSustainableLivingRetrieval",
    "BrightTheoremQAQuestionsRetrieval",
    "BrightTheoremQATheoremsRetrieval",
    "BuiltBenchRetrieval",
    "CIRRIT2IRetrieval",
    "CMUArcticA2TRetrieval",
    "CMUArcticT2ARetrieval",
    "CQADupstackAndroidRetrieval",
    "CQADupstackEnglishRetrieval",
    "CQADupstackGamingRetrieval",
    "CQADupstackGisRetrieval",
    "CQADupstackMathematicaRetrieval",
    "CQADupstackPhysicsRetrieval",
    "CQADupstackProgrammersRetrieval",
    "CQADupstackStatsRetrieval",
    "CQADupstackTexRetrieval",
    "CQADupstackUnixRetrieval",
    "CQADupstackWebmastersRetrieval",
    "CQADupstackWordpressRetrieval",
    "ChatDoctorRetrieval",
    "ChemHotpotQARetrieval",
    "ChemNQRetrieval",
    "ChemRxivRetrieval",
    "ClimateFEVER",
    "ClimateFEVERHardNegatives",
    "ClimateFEVERHardNegativesV2",
    "ClimateFEVERRetrievalv2",
    "ClothoA2TRetrieval",
    "ClothoT2ARetrieval",
    "DAPFAMAllTitlAbsClmToFullTextRetrieval",
    "DAPFAMAllTitlAbsClmToTitlAbsClmRetrieval",
    "DAPFAMAllTitlAbsClmToTitlAbsRetrieval",
    "DAPFAMAllTitlAbsToFullTextRetrieval",
    "DAPFAMAllTitlAbsToTitlAbsClmRetrieval",
    "DAPFAMAllTitlAbsToTitlAbsRetrieval",
    "DAPFAMInTitlAbsClmToFullTextRetrieval",
    "DAPFAMInTitlAbsClmToTitlAbsClmRetrieval",
    "DAPFAMInTitlAbsClmToTitlAbsRetrieval",
    "DAPFAMInTitlAbsToFullTextRetrieval",
    "DAPFAMInTitlAbsToTitlAbsClmRetrieval",
    "DAPFAMInTitlAbsToTitlAbsRetrieval",
    "DAPFAMOutTitlAbsClmToFullTextRetrieval",
    "DAPFAMOutTitlAbsClmToTitlAbsClmRetrieval",
    "DAPFAMOutTitlAbsClmToTitlAbsRetrieval",
    "DAPFAMOutTitlAbsToFullTextRetrieval",
    "DAPFAMOutTitlAbsToTitlAbsClmRetrieval",
    "DAPFAMOutTitlAbsToTitlAbsRetrieval",
    "DBPedia",
    "DBPediaHardNegatives",
    "DBPediaHardNegativesV2",
    "EDIST2ITRetrieval",
    "EmoVDBA2TRetrieval",
    "EmoVDBT2ARetrieval",
    "EncyclopediaVQAIT2ITRetrieval",
    "EnglishFinance1Retrieval",
    "EnglishFinance2Retrieval",
    "EnglishFinance3Retrieval",
    "EnglishFinance4Retrieval",
    "EnglishHealthcare1Retrieval",
    "FEVERHardNegatives",
    "FEVERHardNegativesV2",
    "FaithDialRetrieval",
    "Fashion200kI2TRetrieval",
    "Fashion200kT2IRetrieval",
    "FashionIQIT2IRetrieval",
    "FeedbackQARetrieval",
    "FiQA2018",
    "FinQARetrieval",
    "FinanceBenchRetrieval",
    "Flickr30kI2TRetrieval",
    "Flickr30kT2IRetrieval",
    "GLDv2I2IRetrieval",
    "GLDv2I2TRetrieval",
    "GigaSpeechA2TRetrieval",
    "GigaSpeechT2ARetrieval",
    "GovReportRetrieval",
    "HC3FinanceRetrieval",
    "HagridRetrieval",
    "HatefulMemesI2TRetrieval",
    "HatefulMemesT2IRetrieval",
    "HellaSwag",
    "HiFiTTSA2TRetrieval",
    "HiFiTTST2ARetrieval",
    "HotpotQA",
    "HotpotQAHardNegatives",
    "HotpotQAHardNegativesV2",
    "ImageCoDeT2IRetrieval",
    "InfoSeekIT2ITRetrieval",
    "InfoSeekIT2TRetrieval",
    "JLCorpusA2TRetrieval",
    "JLCorpusT2ARetrieval",
    "LASSA2TRetrieval",
    "LASST2ARetrieval",
    "LEMBNarrativeQARetrieval",
    "LEMBNeedleRetrieval",
    "LEMBPasskeyRetrieval",
    "LEMBQMSumRetrieval",
    "LEMBSummScreenFDRetrieval",
    "LEMBWikimQARetrieval",
    "LIMITRetrieval",
    "LIMITSmallRetrieval",
    "LLaVAIT2TRetrieval",
    "LegalBenchConsumerContractsQA",
    "LegalBenchCorporateLobbying",
    "LegalSummarization",
    "LibriTTSA2TRetrieval",
    "LibriTTST2ARetrieval",
    "LitSearchRetrieval",
    "LoTTERetrieval",
    "MACSA2TRetrieval",
    "MACST2ARetrieval",
    "METI2IRetrieval",
    "MLQuestionsRetrieval",
    "MSCOCOI2TRetrieval",
    "MSCOCOT2IRetrieval",
    "MSMARCOHardNegatives",
    "MSMARCOv2",
    "MedicalQARetrieval",
    "MemotionI2TRetrieval",
    "MemotionT2IRetrieval",
    "NFCorpus",
    "NIGHTSI2IRetrieval",
    "NQHardNegatives",
    "NanoArguAnaRetrieval",
    "NanoClimateFeverRetrieval",
    "NanoDBPediaRetrieval",
    "NanoFEVERRetrieval",
    "NanoFiQA2018Retrieval",
    "NanoHotpotQARetrieval",
    "NanoMSMARCORetrieval",
    "NanoNFCorpusRetrieval",
    "NanoNQRetrieval",
    "NanoQuoraRetrieval",
    "NanoSCIDOCSRetrieval",
    "NanoSciFactRetrieval",
    "NanoTouche2020Retrieval",
    "NarrativeQARetrieval",
    "OKVQAIT2TRetrieval",
    "OVENIT2ITRetrieval",
    "OVENIT2TRetrieval",
    "Quail",
    "QuoraRetrieval",
    "QuoraRetrievalHardNegatives",
    "QuoraRetrievalHardNegativesV2",
    "R2MEDBioinformaticsRetrieval",
    "R2MEDBiologyRetrieval",
    "R2MEDIIYiClinicalRetrieval",
    "R2MEDMedQADiagRetrieval",
    "R2MEDMedXpertQAExamRetrieval",
    "R2MEDMedicalSciencesRetrieval",
    "R2MEDPMCClinicalRetrieval",
    "R2MEDPMCTreatmentRetrieval",
    "RARbCode",
    "RARbMath",
    "ROxfordEasyI2IRetrieval",
    "ROxfordHardI2IRetrieval",
    "ROxfordMediumI2IRetrieval",
    "RP2kI2IRetrieval",
    "RParisEasyI2IRetrieval",
    "RParisHardI2IRetrieval",
    "RParisMediumI2IRetrieval",
    "ReMuQIT2TRetrieval",
    "SOPI2IRetrieval",
    "SciFact",
    "SciMMIRI2TRetrieval",
    "SciMMIRT2IRetrieval",
    "SketchyI2IRetrieval",
    "SpartQA",
    "SpokenSQuADT2ARetrieval",
    "StanfordCarsI2I",
    "TUBerlinT2IRetrieval",
    "TempReasonL1",
    "TempReasonL2Context",
    "TempReasonL2Fact",
    "TempReasonL2Pure",
    "TempReasonL3Context",
    "TempReasonL3Fact",
    "TempReasonL3Pure",
    "TopiOCQARetrieval",
    "TopiOCQARetrievalHardNegatives",
    "Touche2020",
    "Touche2020v3Retrieval",
    "VQA2IT2TRetrieval",
    "VidoreArxivQARetrieval",
    "VidoreDocVQARetrieval",
    "VidoreInfoVQARetrieval",
    "VidoreShiftProjectRetrieval",
    "VidoreSyntheticDocQAAIRetrieval",
    "VidoreSyntheticDocQAEnergyRetrieval",
    "VidoreSyntheticDocQAGovernmentReportsRetrieval",
    "VidoreSyntheticDocQAHealthcareIndustryRetrieval",
    "VidoreTabfquadRetrieval",
    "VidoreTatdqaRetrieval",
    "VisRAGRetArxivQA",
    "VisRAGRetChartQA",
    "VisRAGRetInfoVQA",
    "VisRAGRetMPDocVQA",
    "VisRAGRetPlotQA",
    "VisRAGRetSlideVQA",
    "VisualNewsI2TRetrieval",
    "VisualNewsT2IRetrieval",
    "VizWizIT2TRetrieval",
    "WebQAT2ITRetrieval",
    "WebQAT2TRetrieval",
    "WinoGrande",
]



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class SpokenQAForIC(AbsTaskClassification):
    metadata = TaskMetadata(
        name="SpokenQAForIC",
        description="SpokenQA dataset reformulated as Intent Classification (IC) task",
        reference="https://huggingface.co/datasets/DynamicSuperb/SpokenQA_SLUE",
        dataset={
            "path": "mteb/SpokenQA_SLUE",
            "revision": "97eb2287a0c881538cee9f5db415e80111d96a31",
        },
        type="AudioClassification",
        category="a2c",
        eval_splits=["train"],
        eval_langs=["eng-Latn"],
        main_score="accuracy",
        date=("2023-11-18", "2023-11-18"),
        domains=["Spoken"],
        task_subtypes=["Intent Classification"],
        license="not specified",
        annotations_creators="human-annotated",
        dialect=[],
        modalities=["audio"],
        sample_creation="multiple",
        bibtex_citation=r"""
@misc{shon2023sluephase2benchmarksuite,
  archiveprefix = {arXiv},
  author = {Suwon Shon and Siddhant Arora and Chyi-Jiunn Lin and Ankita Pasad and Felix Wu and Roshan Sharma and Wei-Lun Wu and Hung-Yi Lee and Karen Livescu and Shinji Watanabe},
  eprint = {2212.10525},
  primaryclass = {cs.CL},
  title = {SLUE Phase-2: A Benchmark Suite of Diverse Spoken Language Understanding Tasks},
  url = {https://arxiv.org/abs/2212.10525},
  year = {2023},
}
""",
    )

    input_column_name: str = "audio"
    label_column_name: str = "label"

    is_cross_validation: bool = True

    def dataset_transform(self):
        self.dataset["train"] = self.dataset.pop("test")



from mteb.abstasks import AbsTaskPairClassification
from mteb.abstasks.task_metadata import TaskMetadata


class NMSQAPairClassification(AbsTaskPairClassification):
    metadata = TaskMetadata(
        name="NMSQAPairClassification",
        description="A textless Q&A dataset. Given a pair of audio question and audio answer, is the answer relevant to the question?",
        reference="https://www.researchgate.net/publication/311458869_FMA_A_Dataset_For_Music_Analysis",
        dataset={
            "path": "mteb/NMSQAPairClassification",
            "revision": "d33eea302d8a64c0a2ee094cf39d77c0814fe87a",
        },
        type="AudioPairClassification",
        category="a2a",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="max_ap",
        date=("2016-01-01", "2016-12-31"),
        domains=["Spoken"],
        task_subtypes=["Question answering"],
        license="cc-by-sa-4.0",
        annotations_creators="human-annotated",
        dialect=[],
        modalities=["audio"],
        sample_creation="found",
        bibtex_citation=r"""
@misc{lin2022dualdiscretespokenunit,
  archiveprefix = {arXiv},
  author = {Guan-Ting Lin and Yung-Sung Chuang and Ho-Lam Chung and Shu-wen Yang and Hsuan-Jui Chen and Shuyan Dong and Shang-Wen Li and Abdelrahman Mohamed and Hung-yi Lee and Lin-shan Lee},
  eprint = {2203.04911},
  primaryclass = {cs.CL},
  title = {DUAL: Discrete Spoken Unit Adaptive Learning for Textless Spoken Question Answering},
  url = {https://arxiv.org/abs/2203.04911},
  year = {2022},
}
""",
    )

    input1_column_name: str = "audio1"
    input2_column_name: str = "audio2"
    label_column_name: str = "label"



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata

TEST_SAMPLES = 2048


class RomanianSentimentClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="RomanianSentimentClassification",
        description="An Romanian dataset for sentiment classification.",
        reference="https://arxiv.org/abs/2009.08712",
        dataset={
            "path": "mteb/RomanianSentimentClassification",
            "revision": "0f8df3d483924afb9130020e9f36ef09558fc9a1",
        },
        type="Classification",
        category="t2c",
        modalities=["text"],
        date=("2020-09-18", "2020-09-18"),
        eval_splits=["test"],
        eval_langs=["ron-Latn"],
        main_score="accuracy",
        domains=["Reviews", "Written"],
        task_subtypes=["Sentiment/Hate speech"],
        license="not specified",
        annotations_creators="human-annotated",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{dumitrescu2020birth,
  author = {Dumitrescu, Stefan Daniel and Avram, Andrei-Marius and Pyysalo, Sampo},
  journal = {arXiv preprint arXiv:2009.08712},
  title = {The birth of Romanian BERT},
  year = {2020},
}
""",
        superseded_by="RomanianSentimentClassification.v2",
    )


class RomanianSentimentClassificationV2(AbsTaskClassification):
    metadata = TaskMetadata(
        name="RomanianSentimentClassification.v2",
        description="An Romanian dataset for sentiment classification. This version corrects errors found in the original data. For details, see [pull request](https://github.com/embeddings-benchmark/mteb/pull/2900)",
        reference="https://arxiv.org/abs/2009.08712",
        dataset={
            "path": "mteb/romanian_sentiment",
            "revision": "bf545b83db13cf73ed402749b21a7777e0afdc6a",
        },
        type="Classification",
        category="t2c",
        modalities=["text"],
        date=("2020-09-18", "2020-09-18"),
        eval_splits=["test"],
        eval_langs=["ron-Latn"],
        main_score="accuracy",
        domains=["Reviews", "Written"],
        task_subtypes=["Sentiment/Hate speech"],
        license="not specified",
        annotations_creators="human-annotated",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{dumitrescu2020birth,
  author = {Dumitrescu, Stefan Daniel and Avram, Andrei-Marius and Pyysalo, Sampo},
  journal = {arXiv preprint arXiv:2009.08712},
  title = {The birth of Romanian BERT},
  year = {2020},
}
""",
        adapted_from=["RomanianSentimentClassification"],
    )

    def dataset_transform(
        self,
        num_proc: int | None = None,
    ):
        self.dataset = self.stratified_subsampling(
            self.dataset, seed=self.seed, splits=["test"]
        )



from .ja_cwir_retrieval import JaCWIRRetrieval
from .ja_cwir_retrieval_lite import JaCWIRRetrievalLite
from .ja_gov_faqs_retrieval import JaGovFaqsRetrieval
from .ja_qu_ad_retrieval import JaQuADRetrieval
from .japanese_legal1_retrieval import JapaneseLegal1Retrieval
from .jaqket_retrieval import JaqketRetrieval
from .jaqket_retrieval_lite import JaqketRetrievalLite
from .miracl_ja_retrieval_lite import MIRACLJaRetrievalLite
from .mr_tydi_ja_retrieval_lite import MrTyDiJaRetrievalLite
from .nlp_journal_abs_article_retrieval import (
    NLPJournalAbsArticleRetrieval,
    NLPJournalAbsArticleRetrievalV2,
)
from .nlp_journal_abs_intro_retrieval import (
    NLPJournalAbsIntroRetrieval,
    NLPJournalAbsIntroRetrievalV2,
)
from .nlp_journal_title_abs_retrieval import (
    NLPJournalTitleAbsRetrieval,
    NLPJournalTitleAbsRetrievalV2,
)
from .nlp_journal_title_intro_retrieval import (
    NLPJournalTitleIntroRetrieval,
    NLPJournalTitleIntroRetrievalV2,
)

__all__ = [
    "JaCWIRRetrieval",
    "JaCWIRRetrievalLite",
    "JaGovFaqsRetrieval",
    "JaQuADRetrieval",
    "JapaneseLegal1Retrieval",
    "JaqketRetrieval",
    "JaqketRetrievalLite",
    "MIRACLJaRetrievalLite",
    "MrTyDiJaRetrievalLite",
    "NLPJournalAbsArticleRetrieval",
    "NLPJournalAbsArticleRetrievalV2",
    "NLPJournalAbsIntroRetrieval",
    "NLPJournalAbsIntroRetrievalV2",
    "NLPJournalTitleAbsRetrieval",
    "NLPJournalTitleAbsRetrievalV2",
    "NLPJournalTitleIntroRetrieval",
    "NLPJournalTitleIntroRetrievalV2",
]



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class SentimentAnalysisHindi(AbsTaskClassification):
    metadata = TaskMetadata(
        name="SentimentAnalysisHindi",
        description="Hindi Sentiment Analysis Dataset",
        reference="https://huggingface.co/datasets/OdiaGenAI/sentiment_analysis_hindi",
        dataset={
            "path": "mteb/SentimentAnalysisHindi",
            "revision": "feab4a1cfc55f4b799f4ed902d8967e2ab68425c",
        },
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["train"],
        eval_langs=["hin-Deva"],
        main_score="f1",
        date=("2023-09-15", "2023-10-16"),
        dialect=[],
        domains=["Reviews", "Written"],
        task_subtypes=["Sentiment/Hate speech"],
        license="cc-by-nc-sa-4.0",
        annotations_creators="derived",
        sample_creation="found",
        bibtex_citation=r"""
@misc{OdiaGenAI,
  author = {Shantipriya Parida and Sambit Sekhar and Soumendra Kumar Sahoo and Swateek Jena and Abhijeet Parida and Satya Ranjan Dash and Guneet Singh Kohli},
  howpublished = {{https://huggingface.co/OdiaGenAI}},
  journal = {Hugging Face repository},
  publisher = {Hugging Face},
  title = {OdiaGenAI: Generative AI and LLM Initiative for the Odia Language},
  year = {2023},
}
""",
        superseded_by="SentimentAnalysisHindi.v2",
    )


class SentimentAnalysisHindiV2(AbsTaskClassification):
    metadata = TaskMetadata(
        name="SentimentAnalysisHindi.v2",
        description="Hindi Sentiment Analysis Dataset This version corrects errors found in the original data. For details, see [pull request](https://github.com/embeddings-benchmark/mteb/pull/2900)",
        reference="https://huggingface.co/datasets/OdiaGenAI/sentiment_analysis_hindi",
        dataset={
            "path": "mteb/sentiment_analysis_hindi",
            "revision": "27fc099ce1c5a7295b9231e53a37648cdef6cb79",
        },
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["hin-Deva"],
        main_score="f1",
        date=("2023-09-15", "2023-10-16"),
        dialect=[],
        domains=["Reviews", "Written"],
        task_subtypes=["Sentiment/Hate speech"],
        license="cc-by-nc-sa-4.0",
        annotations_creators="derived",
        sample_creation="found",
        bibtex_citation=r"""
@misc{OdiaGenAI,
  author = {Shantipriya Parida and Sambit Sekhar and Soumendra Kumar Sahoo and Swateek Jena and Abhijeet Parida and Satya Ranjan Dash and Guneet Singh Kohli},
  howpublished = {{https://huggingface.co/OdiaGenAI}},
  journal = {Hugging Face repository},
  publisher = {Hugging Face},
  title = {OdiaGenAI: Generative AI and LLM Initiative for the Odia Language},
  year = {2023},
}
""",
        adapted_from=["SentimentAnalysisHindi"],
    )



from mteb.abstasks.classification import AbsTaskClassification
from mteb.abstasks.task_metadata import TaskMetadata


class FrenkSlClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="FrenkSlClassification",
        description="Slovenian subset of the FRENK dataset. Also available on HuggingFace dataset hub: English subset, Croatian subset.",
        dataset={
            "path": "mteb/FrenkSlClassification",
            "revision": "65ee787b7cc409d51ec6ee4d003596b66cdb70f3",
        },
        reference="https://arxiv.org/pdf/1906.02045",
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["slv-Latn"],
        main_score="accuracy",
        date=("2021-05-28", "2021-05-28"),
        domains=["Social", "Written"],
        task_subtypes=["Sentiment/Hate speech"],
        license="not specified",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@misc{ljubešić2019frenk,
  archiveprefix = {arXiv},
  author = {Nikola Ljubešić and Darja Fišer and Tomaž Erjavec},
  eprint = {1906.02045},
  primaryclass = {cs.CL},
  title = {The FRENK Datasets of Socially Unacceptable Discourse in Slovene and English},
  url = {https://arxiv.org/abs/1906.02045},
  year = {2019},
}
""",
        superseded_by="FrenkSlClassification.v2",
    )


class FrenkSlClassificationV2(AbsTaskClassification):
    metadata = TaskMetadata(
        name="FrenkSlClassification.v2",
        description="Slovenian subset of the FRENK dataset. Also available on HuggingFace dataset hub: English subset, Croatian subset. This version corrects errors found in the original data. For details, see [pull request](https://github.com/embeddings-benchmark/mteb/pull/2900)",
        dataset={
            "path": "mteb/frenk_sl",
            "revision": "3b69facc14651fbd152fda173683a7ecf9125b82",
        },
        reference="https://arxiv.org/pdf/1906.02045",
        type="Classification",
        category="t2c",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["slv-Latn"],
        main_score="accuracy",
        date=("2021-05-28", "2021-05-28"),
        domains=["Social", "Written"],
        task_subtypes=["Sentiment/Hate speech"],
        license="not specified",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@misc{ljubešić2019frenk,
  archiveprefix = {arXiv},
  author = {Nikola Ljubešić and Darja Fišer and Tomaž Erjavec},
  eprint = {1906.02045},
  primaryclass = {cs.CL},
  title = {The FRENK Datasets of Socially Unacceptable Discourse in Slovene and English},
  url = {https://arxiv.org/abs/1906.02045},
  year = {2019},
}
""",
        adapted_from=["FrenkSlClassification"],
    )

    def dataset_transform(
        self,
        num_proc: int | None = None,
    ):
        self.dataset = self.stratified_subsampling(
            self.dataset, seed=self.seed, splits=["test"]
        )



from __future__ import annotations

import hashlib
import json
import logging
import warnings
from collections.abc import Callable, Mapping
from dataclasses import field
from enum import Enum
from functools import partial
from typing import TYPE_CHECKING, Any, Literal, cast

import numpy as np
from huggingface_hub import (
    ModelCard,
    get_safetensors_metadata,
    model_info,
)
from huggingface_hub.errors import (
    GatedRepoError,
    NotASafetensorsRepoError,
    RepositoryNotFoundError,
    SafetensorsParsingError,
)
from pydantic import BaseModel, ConfigDict, field_validator, model_validator
from sentence_transformers import CrossEncoder, SentenceTransformer
from transformers import AutoConfig

from mteb._helpful_enum import HelpfulStrEnum
from mteb._hf_integration.hf_hub_utils import (
    _get_json_from_hub,
    _get_repo_commits,
    _repo_exists,
)
from mteb.languages import check_language_code
from mteb.models.models_protocols import MTEBModels
from mteb.types import ISOLanguageScript, Licenses, Modalities, StrDate, StrURL

if TYPE_CHECKING:
    from collections.abc import Sequence

    from huggingface_hub import (
        ModelCardData,
    )
    from typing_extensions import Self

    from mteb.abstasks import AbsTask
    from mteb.cache import ResultCache
    from mteb.models.models_protocols import EncoderProtocol


logger = logging.getLogger(__name__)

FRAMEWORKS = Literal[
    "Sentence Transformers",
    "PyTorch",
    "GritLM",
    "LLM2Vec",
    "TensorFlow",
    "API",
    "Tevatron",
    "NumPy",
    "PyLate",
    "ColBERT",
    "ColPali",
    "GGUF",
    "safetensors",
    "ONNX",
    "Transformers",
]

MODEL_TYPES = Literal["dense", "cross-encoder", "late-interaction", "sparse", "router"]


class ScoringFunction(HelpfulStrEnum):
    """The scoring function used by the models."""

    COSINE = "cosine"
    DOT_PRODUCT = "dot"
    MAX_SIM = "MaxSim"
    EUCLIDEAN = "euclidean"
    MANHATTAN = "manhattan"
    CUSTOM = "custom"


def _get_loader_name(
    loader: Callable[..., EncoderProtocol] | None,
) -> str | None:
    if loader is None:
        return None
    if hasattr(loader, "func"):  # partial class wrapper
        return loader.func.__name__
    return loader.__name__


class ModelMeta(BaseModel):
    """The model metadata object.

    Attributes:
        loader: The function that loads the model. If None it assumes that the model is not implemented.
        loader_kwargs: The keyword arguments to pass to the loader function.
        name: The name of the model, ideally the name on huggingface. It should be in the format "organization/model_name".
        n_parameters: The total number of parameters in the model, e.g. `7_000_000` for a 7M parameter model. Can be none in case the number of parameters is unknown.
        n_embedding_parameters: The number of parameters used for the embedding layer. Can be None if the number of embedding parameters is not known (e.g. for proprietary models).
        n_active_parameters_override: The number of active parameters used bu model. Should be used **only** for Mixture of Experts models.
        memory_usage_mb: The memory usage of the model in MB. Can be None if the memory usage is not known (e.g. for proprietary models). To calculate it use the `calculate_memory_usage_mb` method.
        max_tokens: The maximum number of tokens the model can handle. Can be None if the maximum number of tokens is not known (e.g. for proprietary
            models).
        embed_dim: The dimension of the embeddings produced by the model. Currently all models are assumed to produce fixed-size embeddings.
        revision: The revision number of the model. If None, it is assumed that the metadata (including the loader) is valid for all revisions of the model.
        release_date: The date the model's revision was released. If None, then release date will be added based on 1st commit in hf repository of model.
        license: The license under which the model is released. Required if open_weights is True.
        open_weights: Whether the model is open source or proprietary.
        public_training_code: A link to the publicly available training code. If None, it is assumed that the training code is not publicly available.
        public_training_data: A link to the publicly available training data. If None, it is assumed that the training data is not publicly available.
        similarity_fn_name: The distance metric used by the model.
        framework: The framework the model is implemented in, can be a list of frameworks e.g. `["Sentence Transformers", "PyTorch"]`.
        reference: A URL to the model's page on huggingface or another source.
        languages: The languages the model is intended to be specified as a 3-letter language code followed by a script code e.g., "eng-Latn" for English
            in the Latin script.
        use_instructions: Whether the model uses instructions E.g. for prompt-based models. This also includes models that require a specific format for
            input, such as "query: {document}" or "passage: {document}".
        citation: The citation for the model. This is a bibtex string.
        training_datasets: A dictionary of datasets that the model was trained on. Names should be names as their appear in `mteb` for example
            {"ArguAna"} if the model is trained on the ArguAna test set. This field is used to determine if a model generalizes zero-shot to
            a benchmark as well as mark dataset contaminations.
        adapted_from: Name of the model from which this model is adapted. For quantizations, fine-tunes, long doc extensions, etc.
        superseded_by: Name of the model that supersedes this model, e.g., nvidia/NV-Embed-v2 supersedes v1.
        model_type: A list of strings representing the type of model.
        modalities: A list of strings representing the modalities the model supports. Default is ["text"].
        contacts: The people to contact in case of a problem in the model, preferably a GitHub handle.
        experiment_kwargs: A dictionary of parameters used in the experiment that are not covered by other fields. This is used to create experiment names for ablation studies and similar experiments.
    """

    model_config = ConfigDict(extra="forbid")

    # loaders
    loader: Callable[..., MTEBModels] | None
    loader_kwargs: dict[str, Any] = field(default_factory=dict)
    name: str | None
    revision: str | None
    release_date: StrDate | None
    languages: list[ISOLanguageScript] | None
    n_parameters: int | None
    n_active_parameters_override: int | None = None
    n_embedding_parameters: int | None = None
    memory_usage_mb: float | None
    max_tokens: float | None
    embed_dim: int | None
    license: Licenses | StrURL | None
    open_weights: bool | None
    public_training_code: str | None
    public_training_data: str | bool | None
    framework: list[FRAMEWORKS]
    reference: StrURL | None = None
    similarity_fn_name: ScoringFunction | None
    use_instructions: bool | None
    training_datasets: set[str] | None
    adapted_from: str | None = None
    superseded_by: str | None = None
    modalities: list[Modalities] = ["text"]
    model_type: list[MODEL_TYPES] = ["dense"]
    citation: str | None = None
    contacts: list[str] | None = None
    experiment_kwargs: Mapping[str, Any] | None = None

    @model_validator(mode="before")
    @classmethod
    def _handle_legacy_is_cross_encoder(cls, data: Any) -> Any:
        """Handle legacy is_cross_encoder field by converting it to model_type.

        This validator handles backward compatibility for the deprecated is_cross_encoder field.
        If is_cross_encoder=True is provided, it adds "cross_encoder" to model_type.
        """
        if isinstance(data, dict) and "is_cross_encoder" in data:
            is_cross_encoder_value = data.pop("is_cross_encoder")

            if is_cross_encoder_value is not None:
                warnings.warn(
                    "is_cross_encoder is deprecated and will be removed in a future version. "
                    "Use model_type=['cross-encoder'] instead.",
                    DeprecationWarning,
                    stacklevel=2,
                )

                model_type = data.get("model_type", ["dense"])

                if is_cross_encoder_value:
                    if "cross-encoder" not in model_type:
                        data["model_type"] = ["cross-encoder"]
                else:
                    if "cross-encoder" in model_type:
                        model_type = [t for t in model_type if t != "cross-encoder"]
                        data["model_type"] = model_type if model_type else ["dense"]

        return data

    @property
    def is_cross_encoder(self) -> bool:
        """Returns True if the model is a cross-encoder.

        Derived from model_type field. A model is considered a cross-encoder if "cross-encoder" is in its model_type list.
        """
        return "cross-encoder" in self.model_type

    @property
    def n_active_parameters(self):
        """Number of active parameters. Assumed to be `n_parameters - n_embedding_parameters`. Can be overwritten using `n_active_parameters_override` e.g. for MoE models."""
        if self.n_active_parameters_override is not None:
            return self.n_active_parameters_override

        if self.n_parameters is not None and self.n_embedding_parameters is not None:
            return self.n_parameters - self.n_embedding_parameters
        return None

    @field_validator("similarity_fn_name", mode="before")
    @classmethod
    def _validate_similarity_fn_name(cls, value: str) -> ScoringFunction | None:
        """Converts the similarity function name to the corresponding enum value.

        Sentence_transformers uses Literal['cosine', 'dot', 'euclidean', 'manhattan'],
        and pylate uses Literal['MaxSim']

        Args:
            value: The similarity function name as a string.

        Returns:
            The corresponding ScoringFunction enum value.
        """
        if type(value) is ScoringFunction or value is None:
            return value
        mapping = {
            "cosine": ScoringFunction.COSINE,
            "dot": ScoringFunction.DOT_PRODUCT,
            "MaxSim": ScoringFunction.MAX_SIM,
        }
        if value in mapping:
            return mapping[value]
        raise ValueError(f"Invalid similarity function name: {value}")

    def to_dict(self):
        """Returns a dictionary representation of the model metadata."""
        dict_repr = self.model_dump()
        loader = dict_repr.pop("loader", None)
        dict_repr["training_datasets"] = (
            list(dict_repr["training_datasets"])
            if isinstance(dict_repr["training_datasets"], set)
            else dict_repr["training_datasets"]
        )
        dict_repr["loader"] = _get_loader_name(loader)
        dict_repr["is_cross_encoder"] = self.is_cross_encoder
        return dict_repr

    @field_validator("languages")
    @classmethod
    def _languages_are_valid(
        cls, languages: list[ISOLanguageScript] | None
    ) -> list[ISOLanguageScript] | None:
        if languages is None:
            return None

        for code in languages:
            check_language_code(code)
        return languages

    @field_validator("name")
    @classmethod
    def _check_name(cls, v: str | None) -> str | None:
        if v is None:
            return v
        if "/" not in v:
            raise ValueError(
                "Model name must be in the format 'organization/model_name'"
            )
        return v

    def load_model(self, device: str | None = None, **kwargs: Any) -> MTEBModels:
        """Loads the model using the specified loader function."""
        if self.loader is None:
            raise NotImplementedError(
                "No model implementation is available for this model."
            )
        if self.name is None:
            raise ValueError("name is not set for ModelMeta. Cannot load model.")

        if self.experiment_kwargs is None:
            self.experiment_kwargs = kwargs if len(kwargs) > 0 else None
        elif len(kwargs) > 0 and self.experiment_kwargs is not None:
            kwargs |= self.experiment_kwargs
            self.experiment_kwargs = kwargs

        # Allow overwrites
        _kwargs = self.loader_kwargs.copy()
        _kwargs.update(kwargs)
        if device is not None:
            _kwargs["device"] = device

        model: MTEBModels = self.loader(self.name, revision=self.revision, **_kwargs)
        model.mteb_model_meta = self  # type: ignore[misc]
        return model

    def model_name_as_path(self) -> str:
        """Returns the model name in a format that can be used as a file path.

        Replaces "/" with "__" and spaces with "_".
        """
        if self.name is None:
            raise ValueError("Model name is not set")
        return self.name.replace("/", "__").replace(" ", "_")

    @property
    def experiment_name(self) -> str | None:
        """Create a filesystem-safe string representation of the experiment parameters.

        Uses deterministic serialization and hashing to ensure stable, bounded output.

        Examples:
            >>> import mteb
            >>> model = mteb.get_model("mteb/baseline-random-encoder", param1="test")
            >>>
            >>> print(model.mteb_model_meta.experiment_name)
            >>> # param1_test
        """
        return _serialize_experiment_kwargs_to_name(
            experiment_kwargs=self.experiment_kwargs
        )

    @property
    def model_name_with_experiment(self) -> str | None:
        """Combines the model name with the experiment parameters for a more descriptive name."""
        if self.name is None:
            return None
        experiment_str = _serialize_experiment_kwargs_to_name(
            experiment_kwargs=self.experiment_kwargs,
            value_field_separator="=",
            kwargs_separator=", ",
        )
        return f"{self.name} ({experiment_str})" if experiment_str else self.name

    @classmethod
    def _detect_cross_encoder_or_dense(
        cls,
        model_name: str,
        revision: str | None,
        config: dict[str, Any] | None,
        sentence_transformers_loader: Callable[..., MTEBModels],
        cross_encoder_loader: Callable[..., MTEBModels],
    ) -> tuple[Callable[..., MTEBModels] | None, MODEL_TYPES]:
        """Detect if model is CrossEncoder or default to dense."""
        if not config:
            logger.warning(
                f"Could not load config.json for {model_name}. "
                "Defaulting to SentenceTransformer loader."
            )
            return sentence_transformers_loader, "dense"

        architectures = config.get("architectures", [])

        is_cross_encoder = any(
            arch.endswith("ForSequenceClassification") for arch in architectures
        )
        if is_cross_encoder:
            return cross_encoder_loader, "cross-encoder"

        if cls._is_causal_lm_reranker(architectures, config, model_name):
            return cross_encoder_loader, "cross-encoder"

        logger.info(
            f"Model {model_name} does not have modules.json or recognized architecture. "
            "Defaulting to SentenceTransformer loader."
        )
        return sentence_transformers_loader, "dense"

    @staticmethod
    def _is_causal_lm_reranker(
        architectures: list[str], config: dict[str, Any], model_name: str
    ) -> bool:
        """Check if model is a CausalLM-style reranker."""
        is_causal_lm = any(arch.endswith("ForCausalLM") for arch in architectures)

        if not is_causal_lm:
            return False

        num_labels = config.get("num_labels", 0)
        model_name_lower = model_name.lower()

        return (
            num_labels > 0
            or "rerank" in model_name_lower
            or "cross-encoder" in model_name_lower
        )

    @classmethod
    def _detect_model_type_and_loader(
        cls,
        model_name: str,
        revision: str | None = None,
        config: dict[str, Any] | None = None,
    ) -> tuple[Callable[..., MTEBModels] | None, MODEL_TYPES]:
        """Detect the model type and appropriate loader based on HuggingFace Hub configuration files.

        This follows the Sentence Transformers architecture detection logic:
        1. Check for modules.json - If present, model is a SentenceTransformer (dense encoder)
        2. If no modules.json, check config.json for architecture:
            - ForSequenceClassification → CrossEncoder
            - CausalLM with reranking indicators → CrossEncoder
        3. Default to dense (SentenceTransformer) if no clear indicators are found

        Detection for CausalLM-style rerankers:
        - Model has ForCausalLM architecture AND
        - Has num_labels > 0 in config, OR
        - Model name contains "rerank" or "cross-encoder"

        Args:
            model_name: The HuggingFace model name
            revision: The model revision
            config: The loaded config.json from the HuggingFace model repository. If not provided, it will be fetched from the hub.


        Returns:
            A tuple of (loader_function, model_type) where:
            - loader_function: A callable that returns MTEBModels, or None if model doesn't exist
            - model_type: One of "dense", "cross-encoder", or "late-interaction"
        """
        from mteb.models import CrossEncoderWrapper, sentence_transformers_loader

        try:
            modules_config = _get_json_from_hub(
                model_name, "modules.json", "model", revision=revision
            )

            if (
                modules_config
            ):  # SentenceTransformer/SparseEncoder (Not support for now)
                return sentence_transformers_loader, "dense"
            else:
                return cls._detect_cross_encoder_or_dense(
                    model_name,
                    revision,
                    config,
                    sentence_transformers_loader,
                    cross_encoder_loader=CrossEncoderWrapper,
                )

        except Exception as e:
            logger.warning(
                f"Error detecting model type for {model_name}: {e}. "
                "Defaulting to SentenceTransformer loader."
            )

        return sentence_transformers_loader, "dense"

    @classmethod
    def create_empty(cls, overwrites: dict[str, Any] | None = None) -> Self:
        """Creates an empty ModelMeta with all fields set to None or empty."""
        empty_model = cls(
            loader=None,
            name=None,
            revision=None,
            release_date=None,
            languages=None,
            n_parameters=None,
            n_embedding_parameters=None,
            memory_usage_mb=None,
            max_tokens=None,
            embed_dim=None,
            license=None,
            open_weights=None,
            public_training_code=None,
            public_training_data=None,
            framework=[],
            reference=None,
            similarity_fn_name=None,
            use_instructions=None,
            training_datasets=None,
            adapted_from=None,
            superseded_by=None,
            citation=None,
            contacts=None,
        )
        if overwrites:
            empty_model = empty_model.model_copy(update=overwrites)

        if empty_model.name is None:
            empty_model.name = "no_model_name/available"
        if empty_model.revision is None:
            empty_model.revision = "no_revision_available"

        return empty_model

    def merge(self, overwrite: Self) -> Self:
        """Merges another this ModelMeta with another ModelMeta.

        Args:
            overwrite: The ModelMeta to merge into this one. Non-None fields in this ModelMeta will overwrite the corresponding fields in this
                ModelMeta. the `framework` and `model_type` fields with combined.

        Returns:
            A new ModelMeta with the merged fields.
        """
        merged_data = self.model_dump()
        overwrite_data = overwrite.model_dump()

        for key, value in overwrite_data.items():
            if (
                key == "name"
                and value == "no_model_name/available"
                and self.name != "no_model_name/available"
            ):
                continue  # skip overwriting name if overwrite has no name available
            if (
                key == "revision"
                and value == "no_revision_available"
                and self.revision != "no_revision_available"
            ):
                continue  # skip overwriting revision if overwrite has no revision available
            if key in ["framework", "model_type"]:
                # Combine lists and remove duplicates
                merged_list = set(merged_data.get(key, [])) | set(value or [])
                merged_data[key] = list(merged_list)
            if value is not None:
                merged_data[key] = value

        return self.model_copy(update=merged_data)

    @classmethod
    def _from_sentence_transformer_model(cls, model: SentenceTransformer) -> Self:
        """Generates a ModelMeta from only a SentenceTransformer model, without fetching any additional metadata from HuggingFace Hub."""
        from mteb.models import sentence_transformers_loader

        name: str | None = (
            model.model_card_data.model_name
            if model.model_card_data.model_name
            else model.model_card_data.base_model
        )
        n_embedding_parameters = (
            cls._get_n_embedding_parameters_from_sentence_transformers(model)
        )
        return cls.create_empty(
            overwrites=dict(
                name=name,
                revision=model.model_card_data.base_model_revision,
                loader=sentence_transformers_loader,
                max_tokens=model.max_seq_length,
                embed_dim=model.get_sentence_embedding_dimension(),
                similarity_fn_name=ScoringFunction.from_str(model.similarity_fn_name),
                framework=["Sentence Transformers", "PyTorch"],
                n_embedding_parameters=n_embedding_parameters,
            )
        )

    @staticmethod
    def _get_n_embedding_parameters_from_sentence_transformers(
        model: SentenceTransformer | CrossEncoder,
    ) -> int | None:
        """Calculates the number of embedding parameters in a SentenceTransformer model

        This is based on the heuristic: `vocab_size * embedding_dim` where vocab_size and embedding_dim are extracted from the model's first
        Transformer module.
        """
        logger.info(
            "Calculating number of embedding parameters for SentenceTransformer model."
        )

        emb = None
        if isinstance(model, CrossEncoder) and hasattr(
            model.model, "get_input_embeddings"
        ):
            emb = model.model.get_input_embeddings()
            return int(np.prod(emb.weight.shape))
        elif isinstance(model, SentenceTransformer):
            vocab = None
            try:
                vocab = len(model.tokenizer.vocab)
            except Exception as e:
                msg = f"Could not determine vocab size for model {model.model_card_data.model_name} and therefore cannot calculate number of embedding parameters. \nError: \n{e}"
                logger.warning(msg)
            embedding_dimensions = model.get_sentence_embedding_dimension()
            if embedding_dimensions is not None and vocab is not None:
                return vocab * embedding_dimensions

        logger.warning(
            f"Model does not have a recognized architecture for calculating embedding parameters (model={model.model_card_data.model_name})."
        )
        return None

    @classmethod
    def _from_cross_encoder_model(cls, model: CrossEncoder) -> Self:
        """Generates a ModelMeta from only a CrossEncoder model, without fetching any additional metadata from HuggingFace Hub."""
        from mteb.models import CrossEncoderWrapper

        return cls.create_empty(
            overwrites=dict(
                loader=CrossEncoderWrapper,
                name=model.model.name_or_path,
                revision=model.config._commit_hash,
                framework=["Sentence Transformers", "PyTorch"],
                model_type=["cross-encoder"],
                n_embedding_parameters=cls._get_n_embedding_parameters_from_sentence_transformers(
                    model
                ),
            )
        )

    @classmethod
    def _from_hub(
        cls,
        model_name: str,
        revision: str | None = None,
    ) -> Self:
        """Generates a ModelMeta from a HuggingFace model name.

        Args:
            model_name: The HuggingFace model name.
            revision: Revision of the model
            fill_missing: Fill missing attributes from the metadata including number of parameters and memory usage.

        Returns:
            The generated ModelMeta.
        """
        loader: Callable[..., MTEBModels] | None
        model_type: MODEL_TYPES

        reference = "https://huggingface.co/" + model_name

        if not _repo_exists(model_name):
            warnings.warn(
                f"Could not find model {model_name} on HuggingFace Hub repository ({reference}). Metadata will be limited."
            )
            return cls.create_empty(
                overwrites=dict(
                    name=model_name,
                    revision=revision,
                )
            )
        config = _get_json_from_hub(
            model_name, "config.json", "model", revision=revision
        )
        loader, model_type = cls._detect_model_type_and_loader(
            model_name, revision, config=config
        )
        card = ModelCard.load(model_name)
        card_data = card.data
        card_data = cast("ModelCardData", card_data)
        try:
            model_config = AutoConfig.from_pretrained(model_name)
        except Exception as e:
            # some models can't load AutoConfig (e.g. `average_word_embeddings_levy_dependency`)
            model_config = None
            logger.warning(
                f"Can't get model configuration for {model_name}. Error: {e}"
            )

        frameworks = cls._get_frameworks_from_hf_tags(model_name) if model_name else []

        if revision is None:
            revisions = _get_repo_commits(model_name, "model")
            revision = revisions[0].commit_id if revisions else None

        model_license = card_data.license if card_data.license != "other" else None
        n_parameters = cls._calculate_num_parameters_from_hub(model_name)
        n_embedding_parameters = cls._estimate_embedding_parameters_from_hub(
            model_name, revision=revision, config=config
        )
        memory_usage_mb = cls._calculate_memory_usage_mb(
            model_name, n_parameters, fetch_from_hf=True
        )

        embedding_dim = getattr(model_config, "hidden_size", None)
        max_tokens = getattr(model_config, "max_position_embeddings", None)

        sbert_config = _get_json_from_hub(
            model_name, "sentence_bert_config.json", "model", revision=revision
        )
        if sbert_config:
            if max_tokens is None:
                max_tokens = sbert_config.get("max_seq_length", None)
        # have model type, similarity function fields
        config_sbert = _get_json_from_hub(
            model_name, "config_sentence_transformers.json", "model", revision=revision
        )
        similarity_fn_name = (
            ScoringFunction.from_str(config_sbert["similarity_fn_name"])
            if config_sbert is not None
            and config_sbert.get("similarity_fn_name") is not None
            else ScoringFunction.COSINE
        )

        return cls.create_empty(
            overwrites=dict(
                loader=loader,
                name=model_name,
                model_type=[model_type],
                revision=revision,
                reference=reference,
                release_date=cls.fetch_release_date(model_name),
                license=model_license,
                framework=frameworks,
                n_parameters=n_parameters,
                n_embedding_parameters=n_embedding_parameters,
                memory_usage_mb=memory_usage_mb,
                max_tokens=max_tokens,
                embed_dim=embedding_dim,
                similarity_fn_name=similarity_fn_name,
            )
        )

    @classmethod
    def from_sentence_transformer_model(
        cls,
        model: SentenceTransformer,
        revision: str | None = None,
        fill_missing: bool = False,
        compute_metadata: bool | None = None,
        fetch_from_hf: bool = False,
    ) -> Self:
        """Generates a ModelMeta from a SentenceTransformer model.

        Args:
            model: SentenceTransformer model.
            revision: Revision of the model
            fill_missing: Fill missing attributes from the metadata including number of parameters and memory usage.
            compute_metadata: Deprecated. Use fill_missing instead.
            fetch_from_hf: Whether to fetch additional metadata from HuggingFace Hub based on the model name. If False, only metadata that can be
                extracted from the SentenceTransformer model will be used.

        Returns:
            The generated ModelMeta.
        """
        if compute_metadata is not None:
            warnings.warn(
                "The compute_metadata parameter is deprecated and will be removed in a future version. "
                f"Use fetch_from_hf instead. Setting `fetch_from_hf={compute_metadata}`.",
                DeprecationWarning,
                stacklevel=2,
            )
            fetch_from_hf = compute_metadata

        if fill_missing is not None:
            warnings.warn(
                "The fill_missing parameter is deprecated and will be removed in a future version. "
                f"Use fetch_from_hf instead. Setting `fetch_from_hf={fill_missing}`.",
                DeprecationWarning,
                stacklevel=2,
            )
            fetch_from_hf = fill_missing

        meta = cls._from_sentence_transformer_model(model)
        if fetch_from_hf:
            if meta.name is None:
                logger.warning(
                    "Model name is not set in metadata extracted from SentenceTransformer model. Cannot fetch additional metadata from HuggingFace Hub."
                )
            else:
                name = cast("str", meta.name)
                meta_hub = cls._from_hub(name, revision)
                # prioritize metadata from the model card but fill missing fields from the hub
                meta = meta_hub.merge(meta)

        return meta

    @classmethod
    def from_hub(
        cls,
        model: str,
        revision: str | None = None,
        fill_missing: bool | None = None,
        compute_metadata: bool | None = None,
    ) -> Self:
        """Generates a ModelMeta for model from HuggingFace hub.

        Args:
            model: Name of the model from HuggingFace hub. For example, `intfloat/multilingual-e5-large`
            revision: Revision of the model
            fill_missing: Deprecated. The fill missing did not add any functionality for this function, but was added for compatibility with
                'from_sentence_transformer_model' and `from_cross_encoder`. It will be removed in a future version.
            compute_metadata: Deprecated. Was superseded by fill_missing.

        Returns:
            The generated ModelMeta.
        """
        if compute_metadata is not None:
            warnings.warn(
                "The compute_metadata parameter is deprecated and will be removed in a future version. It will be ignored.",
                DeprecationWarning,
                stacklevel=2,
            )

        if fill_missing is not None:
            warnings.warn(
                "The fill_missing parameter is deprecated and will be removed in a future version. It will be ignored.",
                DeprecationWarning,
                stacklevel=2,
            )

        meta = cls._from_hub(
            model,
            revision,
        )

        return meta

    @classmethod
    def from_cross_encoder(
        cls,
        model: CrossEncoder,
        revision: str | None = None,
        fill_missing: bool | None = None,
        compute_metadata: bool | None = None,
        fetch_from_hf: bool = False,
    ) -> Self:
        """Generates a ModelMeta from a CrossEncoder.

        Args:
            model: The CrossEncoder model
            revision: Revision of the model
            fill_missing: Fill missing attributes from the metadata including number of parameters and memory usage.
            compute_metadata: Deprecated. Use fill_missing instead.
            fetch_from_hf: Whether to fetch additional metadata from HuggingFace Hub based on the model name. If False, only metadata that can be
                extracted from the CrossEncoder model will be used.

        Returns:
            The generated ModelMeta
        """
        if compute_metadata is not None:
            warnings.warn(
                "The compute_metadata parameter is deprecated and will be removed in a future version. "
                f"Use fetch_from_hf instead. Setting `fetch_from_hf={compute_metadata}`.",
                DeprecationWarning,
                stacklevel=2,
            )
            fetch_from_hf = compute_metadata
        if fill_missing is not None:
            warnings.warn(
                "The fill_missing parameter is deprecated and will be removed in a future version. "
                f"Use fill_missing instead. Setting `fill_missing={fill_missing}`.",
                DeprecationWarning,
                stacklevel=2,
            )
            fetch_from_hf = fill_missing

        meta = cls._from_cross_encoder_model(model)
        if fetch_from_hf:
            name = cast("str", meta.name)
            meta_hub = cls._from_hub(name, revision)
            # prioritize metadata from the model card but fill missing fields from the hub
            meta = meta_hub.merge(meta)

        return meta

    def is_zero_shot_on(self, tasks: Sequence[AbsTask] | Sequence[str]) -> bool | None:
        """Indicates whether the given model can be considered zero-shot or not on the given tasks.

        Returns:
             None if no training data is specified on the model.
        """
        # If no tasks were specified, we're obviously zero-shot
        if not tasks:
            return True
        training_datasets = self.get_training_datasets()
        # If no tasks were specified, we're obviously zero-shot
        if training_datasets is None:
            return None

        if isinstance(tasks[0], str):
            benchmark_datasets = set(tasks)
        else:
            tasks = cast("Sequence[AbsTask]", tasks)
            benchmark_datasets = set()
            for task in tasks:
                benchmark_datasets.add(task.metadata.name)
        intersection = training_datasets & benchmark_datasets
        return len(intersection) == 0

    def get_training_datasets(self) -> set[str] | None:
        """Returns all training datasets of the model including similar tasks."""
        import mteb

        if self.training_datasets is None:
            return None

        training_datasets = self.training_datasets.copy()
        if self.adapted_from is not None:
            try:
                adapted_from_model = mteb.get_model_meta(
                    self.adapted_from, fetch_from_hf=False
                )
                adapted_training_datasets = adapted_from_model.get_training_datasets()
                if adapted_training_datasets is not None:
                    training_datasets |= adapted_training_datasets
            except (ValueError, KeyError) as e:
                msg = f"Could not get source model: {e} in MTEB"
                logger.warning(msg)
                warnings.warn(msg)

        return_dataset = training_datasets.copy()
        visited: set[str] = set()

        for dataset in training_datasets:
            similar_tasks = _collect_similar_tasks(dataset, visited)
            return_dataset |= similar_tasks

        return return_dataset

    def zero_shot_percentage(
        self, tasks: Sequence[AbsTask] | Sequence[str]
    ) -> int | None:
        """Indicates how out-of-domain the selected tasks are for the given model.

        Args:
            tasks: A sequence of tasks or dataset names to evaluate against.

        Returns:
            An integer percentage (0-100) indicating how out-of-domain the tasks are for the model.
            Returns None if no training data is specified on the model or if no tasks are provided.
        """
        training_datasets = self.get_training_datasets()
        if (training_datasets is None) or (not tasks):
            return None
        if isinstance(tasks[0], str):
            benchmark_datasets = set(tasks)
        else:
            tasks = cast("Sequence[AbsTask]", tasks)
            benchmark_datasets = {task.metadata.name for task in tasks}
        overlap = training_datasets & benchmark_datasets
        perc_overlap = 100 * (len(overlap) / len(benchmark_datasets))
        return int(100 - perc_overlap)

    @staticmethod
    def _calculate_num_parameters_from_hub(model_name: str | None = None) -> int | None:
        if not model_name:
            return None
        try:
            safetensors_metadata = get_safetensors_metadata(model_name)
            if len(safetensors_metadata.parameter_count) >= 0:
                return sum(safetensors_metadata.parameter_count.values())
        except (
            NotASafetensorsRepoError,
            SafetensorsParsingError,
            GatedRepoError,
            RepositoryNotFoundError,
        ) as e:
            logger.warning(
                f"Can't calculate number of parameters for {model_name}. Got error {e}"
            )
        return None

    def calculate_num_parameters_from_hub(self) -> int | None:
        """Calculates the number of parameters in the model.

        Returns:
            Number of parameters in the model.
        """
        return self._calculate_num_parameters_from_hub(self.name)

    @staticmethod
    def _estimate_embedding_parameters_from_hub(
        model_name: str | None = None,
        revision: str | None = None,
        config: dict[str, Any] | None = None,
    ) -> int | None:
        """Calculate the number of embedding parameters from the model config (vocab_size * hidden_size).  Note that this is an heuristic that works for many models, but might be incorrect.

        Returns:
            Number of embedding parameters in the model.
        """
        if not model_name:
            return None

        if not config:
            logger.warning(
                f"Could not calculate embedding parameters for {model_name} as config.json could not be loaded"
            )
            return None

        vocab_size = config.get("vocab_size")
        if vocab_size is None and "text_config" in config:
            vocab_size = config["text_config"].get("vocab_size")

        if vocab_size is None:
            logger.warning(
                f"Could not calculate embedding parameters for {model_name} as vocab_size is missing from config"
            )
            return None

        hidden_size = config.get("hidden_size") or config.get("hidden_dim")
        if hidden_size is None and "text_config" in config:
            hidden_size = config["text_config"].get("hidden_size") or config[
                "text_config"
            ].get("hidden_dim")

        if hidden_size is None:
            logger.warning(
                f"Could not calculate embedding parameters for {model_name} as hidden_size/hidden_dim is missing from config"
            )
            return None
        return vocab_size * hidden_size

    @staticmethod
    def _calculate_memory_usage_mb(
        model_name: str,
        n_parameters: int | None,
        *,
        fetch_from_hf: bool = False,
    ) -> int | None:
        MB = 1024**2  # noqa: N806

        if fetch_from_hf:
            try:
                safetensors_metadata = get_safetensors_metadata(model_name)
                if safetensors_metadata.parameter_count:
                    dtype_size_map = {
                        "F64": 8,  # 64-bit float
                        "F32": 4,  # 32-bit float (FP32)
                        "F16": 2,  # 16-bit float (FP16)
                        "BF16": 2,  # BFloat16
                        "I64": 8,  # 64-bit integer
                        "I32": 4,  # 32-bit integer
                        "I16": 2,  # 16-bit integer
                        "I8": 1,  # 8-bit integer
                        "U8": 1,  # Unsigned 8-bit integer
                        "BOOL": 1,  # Boolean (assuming 1 byte per value)
                    }
                    total_memory_bytes = sum(
                        parameters * dtype_size_map.get(dtype, 4)
                        for dtype, parameters in safetensors_metadata.parameter_count.items()
                    )
                    return round(total_memory_bytes / MB)  # Convert to MB
            except (
                NotASafetensorsRepoError,
                SafetensorsParsingError,
                GatedRepoError,
                RepositoryNotFoundError,
            ) as e:
                logger.warning(
                    f"Can't calculate memory usage for {model_name}. Got error {e}"
                )

        if n_parameters is None:
            return None
        # Model memory in bytes. For FP32 each parameter is 4 bytes.
        model_memory_bytes = n_parameters * 4

        # Convert to MB
        model_memory_mb = model_memory_bytes / MB
        return round(model_memory_mb)

    def calculate_memory_usage_mb(self, fetch_from_hf: bool = False) -> int | None:
        """Calculates the memory usage of the model in MB.

        Args:
            fetch_from_hf: If True, fetch safetensors metadata from HuggingFace Hub
                to get precise dtype-aware memory usage. If False (default), estimate
                from n_parameters assuming FP32 (4 bytes per parameter).

        Returns:
            The memory usage of the model in MB, or None if it cannot be determined.
        """
        if "API" in self.framework or self.name is None:
            return None

        return self._calculate_memory_usage_mb(
            self.name, self.n_parameters, fetch_from_hf=fetch_from_hf
        )

    @staticmethod
    def fetch_release_date(model_name: str) -> StrDate | None:
        """Fetches the release date from HuggingFace Hub based on the first commit.

        Returns:
            The release date in YYYY-MM-DD format, or None if it cannot be determined.
        """
        commits = _get_repo_commits(repo_id=model_name, repo_type="model")
        if commits:
            initial_commit = commits[-1]
            release_date = initial_commit.created_at.strftime("%Y-%m-%d")
            return release_date
        return None

    @staticmethod
    def _get_frameworks_from_hf_tags(model_name: str) -> list[FRAMEWORKS]:
        """Extract frameworks supported by the model from HuggingFace model tags.

        Args:
            model_name: HuggingFace model name

        Returns:
            List of framework names found in tags. Defaults to empty list if no frameworks found.
        """
        try:
            info = model_info(model_name)
            if not info.tags:
                return []
        except Exception as e:
            logger.warning(
                f"Failed to fetch frameworks from HuggingFace tags for {model_name}: {e}"
            )
            return []

        # Mapping from HuggingFace tags to MTEB framework names
        tag_to_framework: dict[str, FRAMEWORKS] = {
            "sentence-transformers": "Sentence Transformers",
            "transformers": "Transformers",
            "onnx": "ONNX",
            "safetensors": "safetensors",
            "gguf": "GGUF",
        }

        # Assume PyTorch support by default
        # TODO: could be detected from repo as well: https://github.com/embeddings-benchmark/mteb/issues/4104
        frameworks: list[FRAMEWORKS] = ["PyTorch"]

        for framework_tag in tag_to_framework.keys():
            if framework_tag in info.tags:
                frameworks.append(tag_to_framework[framework_tag])

        return frameworks

    def to_python(self) -> str:
        """Returns a string representation of the model."""
        return _pydantic_instance_to_code(self, exclude_fields=["experiment_kwargs"])

    def push_eval_results(
        self,
        user: str | None = None,
        *,
        tasks: Sequence[AbsTask] | Sequence[str] | None = None,
        cache: ResultCache | None = None,
        create_pr: bool = False,
    ) -> None:
        """Pushes the evaluation results of the model to the HuggingFace Hub.

        Args:
            user: The user or organization of results source.
            tasks: The tasks to push results for. If None, results for all tasks will be pushed.
            cache: The ResultCache containing the evaluation results to push.
            create_pr: Whether to create a pull request for the model card update if the model card already exists on the HuggingFace Hub. If False, the model card will be updated directly without a pull request.
        """
        from mteb.cache import ResultCache

        if cache is None:
            cache = ResultCache()

        benchmark_result = cache.load_results(
            models=[self],
            tasks=tasks,
        )
        model_result = benchmark_result.model_results[0]
        model_result.push_model_results(
            user=user,
            create_pr=create_pr,
        )


def _pydantic_instance_to_code(
    model: BaseModel,
    indent: int = 4,
    *,
    only_set_fields: bool = False,
    exclude_fields: Sequence[str] | None = None,
) -> str:
    """Convert a Pydantic model instance into valid Python constructor code.

    If only_set_fields=True, only fields explicitly provided at model construction
    time are printed (i.e., excludes fields that came only from defaults).

    Arguments:
        model: The Pydantic model to convert.
        indent: The indentation to use.
        only_set_fields: If True, only fields explicitly provided at model construction time
        exclude_fields: Fields to exclude from the output, regardless of whether they were set or not.
    """
    cls_name = model.__class__.__name__
    pad = " " * indent
    lines: list[str] = [f"{cls_name}("]

    model_fields = list(type(model).model_fields.keys())

    if only_set_fields:
        field_names = [n for n in model_fields if n in model.model_fields_set]
    else:
        field_names = model_fields

    for field_name in field_names:
        if exclude_fields and field_name in exclude_fields:
            continue
        value = getattr(model, field_name)
        value_code = _value_to_code(value, indent)
        lines.append(f"{pad}{field_name}={value_code},")

    lines.append(")")
    return "\n".join(lines)


def _value_to_code(value: Any, indent: int) -> str:
    """Convert a Python value into valid Python source code."""
    if isinstance(value, BaseModel):
        return _pydantic_instance_to_code(value, indent, only_set_fields=True)

    if callable(value):
        if isinstance(value, partial):
            return value.func.__name__
        return value.__name__

    if isinstance(value, Enum):
        return f"{value.__class__.__name__}.{value.name}"

    if isinstance(value, str):
        return repr(value)

    if isinstance(value, list):
        if not value:
            return "[]"
        inner = ", ".join(_value_to_code(v, indent) for v in value)
        return f"[{inner}]"

    if isinstance(value, set):
        if not value:
            return "set()"
        inner = ", ".join(_value_to_code(v, indent) for v in sorted(value))
        return f"{{{inner}}}"

    if isinstance(value, dict):
        if not value:
            return "{}"
        inner = ", ".join(
            f"{_value_to_code(k, indent)}: {_value_to_code(v, indent)}"
            for k, v in value.items()
        )
        return f"{{{inner}}}"

    return repr(value)


def _collect_similar_tasks(dataset: str, visited: set[str]) -> set[str]:
    """Recursively collect all similar tasks for a given dataset.

    Args:
        dataset: The dataset for which to find similar tasks.
        visited: A set to keep track of visited datasets to avoid cycles.

    Returns:
        A set of similar tasks.
    """
    from mteb.get_tasks import _SIMILAR_TASKS

    if dataset in visited:
        return set()

    visited.add(dataset)
    similar = set()

    # Check if dataset is a key in SIMILAR_TASKS
    if dataset in _SIMILAR_TASKS:
        for similar_task in _SIMILAR_TASKS[dataset]:
            similar.add(similar_task)
            similar.update(_collect_similar_tasks(similar_task, visited))

    # Check if dataset appears as a value in SIMILAR_TASKS
    for parent, children in _SIMILAR_TASKS.items():
        if dataset in children:
            similar.add(parent)
            similar.update(_collect_similar_tasks(parent, visited))

    return similar


def _serialize_experiment_kwargs_to_name(
    experiment_kwargs: Mapping[str, Any] | None,
    value_field_separator: str = "_",
    kwargs_separator: str = "__",
) -> str | None:
    if experiment_kwargs is None or len(experiment_kwargs) == 0:
        return None

    invalid_chars = set('<>:"|?*\\/\0')

    def _serialize_value(value: Any) -> str:
        """Convert value to deterministic string representation."""
        if isinstance(value, (str, int, float, bool)) or value is None:
            value = str(value)
            for invalid_char in invalid_chars:
                value = value.replace(invalid_char, "_")
            return value
        if isinstance(value, (list, tuple)):
            return f"[{','.join(_serialize_value(v) for v in value)}]"
        if isinstance(value, dict):
            items = sorted(value.items())
            return f"{{{','.join(f'{k}:{_serialize_value(v)}' for k, v in items)}}}"
        if isinstance(value, Enum):
            return f"{value.__class__.__name__}.{value.name}"

        # Handle common scientific types
        if hasattr(value, "__module__") and value.__module__ == "numpy":
            # numpy arrays and scalars
            return f"np_{hashlib.sha256(np.asarray(value).tobytes()).hexdigest()[:8]}"

        # Handle pydantic models and dataclasses
        if isinstance(value, BaseModel):
            # Use model_dump for deterministic JSON representation
            json_str = json.dumps(value.model_dump(), sort_keys=True)
            digest = hashlib.sha256(json_str.encode("utf-8")).hexdigest()[:8]
            return f"{value.__class__.__name__}_{digest}"

        raise ValueError(
            f"experiment_kwargs contains non-serializable type {type(value).__name__}. "
            f"Only JSON-serializable types (str, int, float, bool, list, dict, None), "
            f"Enums, numpy arrays, and Pydantic models are supported."
        )

    params_str = kwargs_separator.join(
        f"{key}{value_field_separator}{_serialize_value(value)}"
        for key, value in sorted(experiment_kwargs.items())
    )

    # If too long or contains invalid chars, use hash
    max_length = 200

    if len(params_str) > max_length or any(c in invalid_chars for c in params_str):
        param_hash = hashlib.sha256(params_str.encode()).hexdigest()[:16]
        return f"exp_{param_hash}"

    return params_str



from __future__ import annotations

import base64
import logging
import os
import time
from concurrent.futures import ThreadPoolExecutor, as_completed
from io import BytesIO
from typing import TYPE_CHECKING, Any

import requests
import torch
from torch.utils.data import DataLoader

from mteb._requires_package import requires_package
from mteb.models.abs_encoder import AbsEncoder
from mteb.models.model_implementations.bge_models import bge_chinese_training_data
from mteb.models.model_implementations.nvidia_models import nvidia_training_datasets
from mteb.models.model_meta import ModelMeta
from mteb.types import PromptType

if TYPE_CHECKING:
    from PIL import Image

    from mteb.abstasks.task_metadata import TaskMetadata
    from mteb.types import Array, BatchedInput


logger = logging.getLogger(__name__)


def pil_to_base64(image, format="jpeg"):
    buffer = BytesIO()
    image.save(buffer, format=format)
    img_bytes = buffer.getvalue()
    encoded_bytes = base64.b64encode(img_bytes)
    return encoded_bytes.decode("utf-8")


def multimodal_embedding(image_base64=None, text_content=None):
    auth_token = os.getenv("VOLCES_AUTH_TOKEN")
    model_name = "doubao-embedding-vision-250615"
    api_url = "https://ark.cn-beijing.volces.com/api/v3/embeddings/multimodal"

    headers = {
        "Authorization": f"Bearer {auth_token}",
        "x-ark-vlm1": "true",
        "Content-Type": "application/json",
    }

    if image_base64 is not None and text_content is None:
        inputs = []
        for image in image_base64:
            image_format = "jpeg"
            image_data = f"data:image/{image_format};base64,{image}"
            inputs.append({"type": "image_url", "image_url": {"url": image_data}})

        payload = {"model": model_name, "input": inputs}
    elif image_base64 is None and text_content is not None:
        payload = {
            "model": model_name,
            "input": [
                {"type": "text", "text": text_content},
            ],
        }
    else:
        inputs = []
        for image in image_base64:
            image_format = "jpeg"
            image_data = f"data:image/{image_format};base64,{image}"
            inputs.append({"type": "image_url", "image_url": {"url": image_data}})
        inputs.append({"type": "text", "text": text_content})
        payload = {"model": model_name, "input": inputs}

    try:
        response = requests.post(url=api_url, headers=headers, json=payload, timeout=10)

        response.raise_for_status()
        return response.json()

    except requests.exceptions.HTTPError as http_err:
        logger.error(f"HTTP error ({http_err.response.status_code}): {http_err}")
    except requests.exceptions.JSONDecodeError:
        logger.error("Error:The response is not in valid JSON format")
    except requests.exceptions.Timeout:
        logger.error("Error:Request timeout")
    except Exception as e:
        logger.error(f"Unknown error: {str(e)}")

    return None


def multi_thread_encode(sentences, batch_size=1, max_workers=8):
    batches = []
    for idx in range(0, len(sentences), batch_size):
        batches.append((idx // batch_size, sentences[idx : idx + batch_size]))

    n_batches = len(batches)
    results = [None] * n_batches  # Pre-allocated result list
    all_embeddings = []  # Final ordered embeddings

    def _process_batch(batch_idx, batch_sentences):
        sentence = batch_sentences[0]

        retries = 5
        while retries > 0:
            try:
                resp = multimodal_embedding(text_content=sentence)
                embedding = torch.tensor(resp["data"]["embedding"])
                break
            except Exception as e:
                time.sleep(1)
                logger.warning(f"Retrying... {retries} retries left. Error: {str(e)}")
                retries -= 1
                if retries == 0:
                    raise e
        return batch_idx, embedding

    with ThreadPoolExecutor(max_workers=max_workers) as executor:
        futures = {
            executor.submit(_process_batch, idx, batch): idx for idx, batch in batches
        }

        for future in as_completed(futures):
            batch_idx, embeddings = future.result()
            results[batch_idx] = embeddings

    for batch_embeddings in results:
        all_embeddings.append(batch_embeddings)

    all_embeddings = torch.stack(all_embeddings, dim=0)
    all_embeddings = torch.nn.functional.normalize(all_embeddings, dim=-1)

    return all_embeddings.float().cpu()


doubao_embedding_training_data = (
    {
        "PAWSX",
        "QBQTC",
        "STSB",
        "TNews",
        "Waimai",
        "IFlyTek",
        "MassiveScenarioClassification",
    }
    | bge_chinese_training_data
    | nvidia_training_datasets
)


class Seed16EmbeddingWrapper(AbsEncoder):
    def __init__(
        self,
        model_name: str,
        revision: str,
        max_tokens: int,
        tokenizer_name: str = "cl100k_base",
        embed_dim: int | None = None,
        available_embed_dims: list[int | None] = [None],
        **kwargs,
    ) -> None:
        """Wrapper for Seed embedding API."""
        requires_package(
            self,
            "volcenginesdkarkruntime",
            "pip install mteb[ark]",
            "tiktoken",
        )
        import tiktoken

        self._model_name = model_name
        self._max_tokens = max_tokens
        self._embed_dim = embed_dim
        self._available_embed_dims = available_embed_dims
        self._encoding = tiktoken.get_encoding(tokenizer_name)

    def truncate_text_tokens(self, text: str) -> str:
        """Truncate a string to have `max_tokens` according to the given encoding.

        Args:
            text: The input string to be truncated.

        Returns:
            The truncated string.
        """
        truncated_sentence = self._encoding.encode(text)[: self._max_tokens]
        return self._encoding.decode(truncated_sentence)

    def get_text_embeddings(
        self,
        sentences: list[str],
        *,
        task_name: str | None = None,
        prompt_type: PromptType | None = None,
        batch_size: int = 32,
    ) -> Array:
        trimmed_sentences = []
        for sentence in sentences:
            encoded_sentence = self._encoding.encode(sentence)
            if len(encoded_sentence) > self._max_tokens:
                truncated_sentence = self.truncate_text_tokens(sentence)
                trimmed_sentences.append(truncated_sentence)
            else:
                trimmed_sentences.append(sentence)

        assert (
            self._embed_dim is None or self._embed_dim in self._available_embed_dims
        ), (
            f"Available embed_dims are {self._available_embed_dims}, found {self._embed_dim}"
        )

        if (
            prompt_type == PromptType("query") or prompt_type is None
        ) and task_name in TASK_NAME_TO_INSTRUCTION:
            instruction = TASK_NAME_TO_INSTRUCTION[task_name]
            trimmed_sentences = [instruction.format(i) for i in trimmed_sentences]

        outputs = multi_thread_encode(trimmed_sentences)

        if self._embed_dim is not None:
            outputs = outputs[:, : self._embed_dim]
        outputs = torch.nn.functional.normalize(outputs, p=2, dim=1)

        return outputs.float()

    def get_image_embeddings(
        self,
        images: list[Image.Image],
        *,
        task_name: str | None = None,
        prompt_type: PromptType | None = None,
        batch_size: int = 32,
        **kwargs: Any,
    ) -> Array:
        import torchvision.transforms.functional as F

        assert (
            self._embed_dim is None or self._embed_dim in self._available_embed_dims
        ), (
            f"Available embed_dims are {self._available_embed_dims}, found {self._embed_dim}"
        )

        if (
            prompt_type == PromptType("query") or prompt_type is None
        ) and task_name in TASK_NAME_TO_INSTRUCTION:
            instruction = TASK_NAME_TO_INSTRUCTION[task_name]
        else:
            instruction = ""

        if isinstance(images, DataLoader):
            images_base64 = []
            for batch in images:
                images_base64.extend([pil_to_base64(F.to_pil_image(b)) for b in batch])
        else:
            images_base64 = [pil_to_base64(image) for image in images]
        outputs = []
        for image in images_base64:
            if instruction == "":
                resp = multimodal_embedding(image_base64=[image])
            else:
                resp = multimodal_embedding(
                    image_base64=[image], text_content=instruction
                )
            embedding = torch.tensor(resp["data"]["embedding"])
            embedding = torch.reshape(embedding, (1, -1))

        outputs = torch.stack(outputs, dim=0)

        if self._embed_dim is not None:
            outputs = outputs[:, : self._embed_dim]
        outputs = torch.nn.functional.normalize(outputs, p=2, dim=1)
        return outputs.float()

    def get_fused_embeddings(
        self,
        texts: list[str] | None = None,
        images: list[Image.Image] | DataLoader | None = None,
        fusion_mode="sum",
        **kwargs: Any,
    ) -> Array:
        assert (
            self._embed_dim is None or self._embed_dim in self._available_embed_dims
        ), (
            f"Available embed_dims are {self._available_embed_dims}, found {self._embed_dim}"
        )

        assert len(texts) == len(images)
        images_base64 = [pil_to_base64(image) for image in images]

        outputs = []
        for i in range(len(images_base64)):
            resp = multimodal_embedding(
                image_base64=[images_base64[i]], text_content=texts[i]
            )
            embedding = torch.tensor(resp["data"]["embedding"])
            embedding = torch.reshape(embedding, (1, -1))

        outputs = torch.stack(outputs, dim=0)

        if self._embed_dim is not None:
            outputs = outputs[:, : self._embed_dim]
        outputs = torch.nn.functional.normalize(outputs, p=2, dim=1)
        return outputs.float()

    def encode(
        self,
        inputs: DataLoader[BatchedInput],
        *,
        task_metadata: TaskMetadata,
        hf_split: str,
        hf_subset: str,
        prompt_type: PromptType | None = None,
        **kwargs: Any,
    ) -> Array:
        if "text" in inputs.dataset.features and "image" in inputs.dataset.features:
            sentences = [text for batch in inputs for text in batch["text"]]
            images = [image for batch in inputs for image in batch["image"]]
            return self.get_fused_embeddings(
                texts=sentences,
                images=images,
                **kwargs,
            )
        if "text" in inputs.dataset.features:
            sentences = [text for batch in inputs for text in batch["text"]]
            return self.get_text_embeddings(
                sentences,
                task_name=task_metadata.name,
                prompt_type=prompt_type,
                **kwargs,
            )
        if "image" in inputs.dataset.features:
            images = [image for batch in inputs for image in batch["image"]]
            return self.get_image_embeddings(
                images, task_name=task_metadata.name, prompt_type=prompt_type, **kwargs
            )
        raise ValueError


TASK_NAME_TO_INSTRUCTION = {
    "ArguAna": "Given a claim, find documents that refute the claim\n{}",
    "ClimateFEVERHardNegatives": "Given a claim, retrieve documents that support or refute the claim\n{}",
    "FEVERHardNegatives": "Given a claim, retrieve documents that support or refute the claim\n{}",
    "FiQA2018": "Given a financial question, retrieve user replies that best answer the question\n{}",
    "HotpotQAHardNegatives": "Given a multi-hop question, retrieve documents that can help answer the question\n{}",
    "SCIDOCS": "Given a title of a scientific paper, retrieve the titles of other relevant papers\n{}",
    "Touche2020Retrieval.v3": "Given a question, retrieve detailed and persuasive arguments that answer the question\n{}",
    "TRECCOVID": "Given a query on COVID-19, retrieve documents that answer the query\n{}",
    "AskUbuntuDupQuestions": "Retrieve duplicate questions from AskUbuntu forum\n{}",
    "MindSmallReranking": "Retrieve relevant news articles based on user browsing history\n{}",
    "SprintDuplicateQuestions": "Retrieve semantically similar text\n{}",
    "TwitterSemEval2015": "Retrieve semantically similar text\n{}",
    "TwitterURLCorpus": "Retrieve semantically similar text\n{}",
    "CQADupstackGamingRetrieval": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question\n{}",
    "CQADupstackUnixRetrieval": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question\n{}",
    "DuRetrieval": "为这个句子生成表示以用于检索相关内容：{}",
    "T2Retrieval": "为这个句子生成表示以用于检索相关内容：{}",
    "MMarcoRetrieval": "为这个句子生成表示以用于检索相关内容：{}",
    "MMarcoReranking": "为这个句子生成表示以用于检索相关内容：{}",
    "T2Reranking": "为这个句子生成表示以用于检索相关内容：{}",
    "CMedQAv1-reranking": "为这个句子生成表示以用于检索相关内容：{}",
    "CMedQAv2-reranking": "为这个句子生成表示以用于检索相关内容：{}",
    "CovidRetrieval": "为这个句子生成表示以用于检索相关内容：{}",
    "CmedqaRetrieval": "为这个句子生成表示以用于检索相关内容：{}",
    "VideoRetrieval": "为这个句子生成表示以用于检索相关内容：{}",
    "EcomRetrieval": "为这个句子生成表示以用于检索相关内容：{}",
    "MedicalRetrieval": "为这个句子生成表示以用于检索相关内容：{}",
    "ATEC": "Retrieve semantically similar text\n{}",
    "BQ": "Retrieve semantically similar text\n{}",
    "LCQMC": "Retrieve semantically similar text\n{}",
    "PAWSX": "Retrieve semantically similar text\n{}",
    "STSB": "Retrieve semantically similar text\n{}",
    "AFQMC": "Retrieve semantically similar text\n{}",
    "QBQTC": "Retrieve semantically similar text\n{}",
    "STS22.v2": "Retrieve semantically similar text\n{}",
    "BIOSSES": "Retrieve semantically similar text\n{}",
    "SICK-R": "Retrieve semantically similar text\n{}",
    "STS12": "Retrieve semantically similar text\n{}",
    "STS13": "Retrieve semantically similar text\n{}",
    "STS14": "Retrieve semantically similar text\n{}",
    "STS15": "Retrieve semantically similar text\n{}",
    "STS17": "Retrieve semantically similar text\n{}",
    "STSBenchmark": "Retrieve semantically similar text\n{}",
    "SummEvalSummarization.v2": "Retrieve semantically similar text\n{}",
    "Ocnli": "Retrieve semantically similar text\n{}",
    "Cmnli": "Retrieve semantically similar text\n{}",
    "TNews": "Classify the fine-grained category of the given news title\n{}",
    "IFlyTek": "Given an App description text, find the appropriate fine-grained category\n{}",
    "MultilingualSentiment": "Classify sentiment of the customer review into positive, neutral, or negative\n{}",
    "JDReview": "Classify the customer review for iPhone on e-commerce platform into positive or negative\n{}",
    "OnlineShopping": "Classify the customer review for online shopping into positive or negative\n{}",
    "Waimai": "Classify the customer review from a food takeaway platform into positive or negative\n{}",
    "AmazonCounterfactualClassification": "Classify a given Amazon customer review text as either counterfactual or not-counterfactual\n{}",
    "Banking77Classification": "Given a online banking query, find the corresponding intents\n{}",
    "ImdbClassification": "Classify the sentiment expressed in the given movie review text from the IMDB dataset\n{}",
    "MassiveIntentClassification": "Given a user utterance as query, find the user intents\n{}",
    "MassiveScenarioClassification": "Given a user utterance as query, find the user scenarios\n{}",
    "MTOPDomainClassification": "Classify the intent domain of the given utterance in task-oriented conversation\n{}",
    "ToxicConversationsClassification": "Classify the given comments as either toxic or not toxic\n{}",
    "TweetSentimentExtractionClassification": "Classify the sentiment of a given tweet as either positive, negative, or neutral\n{}",
    "ArXivHierarchicalClusteringP2P": "Identify the main and secondary category of Arxiv papers based on the titles and abstracts\n{}",
    "ArXivHierarchicalClusteringS2S": "Identify the main and secondary category of Arxiv papers based on the titles\n{}",
    "BiorxivClusteringP2P.v2": "Identify the main category of Biorxiv papers based on the titles and abstracts\n{}",
    "MedrxivClusteringP2P.v2": "Identify the main category of Medrxiv papers based on the titles and abstracts\n{}",
    "MedrxivClusteringS2S.v2": "Identify the main category of Medrxiv papers based on the titles\n{}",
    "StackExchangeClustering.v2": "Identify the topic or theme of StackExchange posts based on the titles\n{}",
    "StackExchangeClusteringP2P.v2": "Identify the topic or theme of StackExchange posts based on the given paragraphs\n{}",
    "TwentyNewsgroupsClustering.v2": "Identify the topic or theme of the given news articles\n{}",
    "CLSClusteringS2S": "Identify the main category of scholar papers based on the titles\n{}",
    "CLSClusteringP2P": "Identify the main category of scholar papers based on the titles and abstracts\n{}",
    "ThuNewsClusteringS2S": "Identify the topic or theme of the given news articles based on the titles\n{}",
    "ThuNewsClusteringP2P": "Identify the topic or theme of the given news articles based on the titles and contents\n{}",
}


seed_embedding = ModelMeta(
    name="Bytedance/Seed1.6-embedding",
    model_type=["dense"],
    revision="1",
    release_date="2025-06-18",
    languages=[
        "eng-Latn",
        "zho-Hans",
    ],
    loader=Seed16EmbeddingWrapper,
    loader_kwargs=dict(
        max_tokens=32000,
        available_embed_dims=[2048, 1024],
    ),
    max_tokens=32768,
    embed_dim=2048,
    open_weights=False,
    n_parameters=None,
    n_embedding_parameters=None,
    memory_usage_mb=None,
    license=None,
    reference="https://seed1-6-embedding.github.io/",
    similarity_fn_name="cosine",
    framework=["API"],
    use_instructions=True,
    training_datasets=doubao_embedding_training_data,
    public_training_code=None,
    public_training_data=None,
)



from datasets import load_dataset

from mteb.abstasks.retrieval import AbsTaskRetrieval
from mteb.abstasks.task_metadata import TaskMetadata


def _load_data(
    path: str,
    splits: str,
    revision: str | None = None,
):
    corpus = {}
    queries = {}
    relevant_docs = {}

    for split in splits:
        query_ds = load_dataset(
            path,
            "queries",
            split=split,
            revision=revision,
        )
        query_ds = query_ds.map(
            lambda x: {
                "id": f"query-{split}-{x['query-id']}",
                "text": x["query"],
                "modality": "text",
            },
            remove_columns=["query-id", "query"],
        )
        queries[split] = query_ds

        corpus_ds = load_dataset(
            path,
            "corpus",
            split=split,
            revision=revision,
        )
        corpus_ds = corpus_ds.map(
            lambda x: {
                "id": f"corpus-{split}-{x['corpus-id']}",
                "modality": "image",
            },
            remove_columns=["corpus-id"],
        )
        corpus[split] = corpus_ds

        qrels_ds = load_dataset(
            path,
            "qrels",
            split=split,
            revision=revision,
        )
        relevant_docs[split] = {}
        for row in qrels_ds:
            qid = f"query-{split}-{row['query-id']}"
            did = f"corpus-{split}-{row['corpus-id']}"
            if qid not in relevant_docs[split]:
                relevant_docs[split][qid] = {}
            relevant_docs[split][qid][did] = int(row["score"])

    return corpus, queries, relevant_docs


class VidoreArxivQARetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreArxivQARetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/arxivqa_test_subsampled_beir",
            "revision": "179762404662be6bf48c30b4fb2b2ef8c6891290",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreDocVQARetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreDocVQARetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/docvqa_test_subsampled_beir",
            "revision": "e78cd130055fcb8d69bb0ff4115c4712a157f3d3",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreInfoVQARetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreInfoVQARetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/infovqa_test_subsampled_beir",
            "revision": "74d396242cc281c021eeb38d0ee5f6f30afc1fad",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreTabfquadRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreTabfquadRetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/tabfquad_test_subsampled_beir",
            "revision": "24a4541c4c461f5ff4f4af4e97ec820715281a06",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreTatdqaRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreTatdqaRetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/tatdqa_test_beir",
            "revision": "dc7924ec102addd7f85c1ccfdd8625848179f615",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreShiftProjectRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreShiftProjectRetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/shiftproject_test_beir",
            "revision": "78e6f5ad3bbc1af50ae9c0f006f57462213269fb",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreSyntheticDocQAAIRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreSyntheticDocQAAIRetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/syntheticDocQA_artificial_intelligence_test_beir",
            "revision": "12c5b7a81fc19d66f1844642acdb88e8ad79af16",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
        adapted_from=["VidoreDocVQARetrieval"],
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreSyntheticDocQAEnergyRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreSyntheticDocQAEnergyRetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/syntheticDocQA_energy_test_beir",
            "revision": "eda52c9a0519252cfaacb7ae5e5da516b7d4b8cb",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
        adapted_from=["VidoreDocVQARetrieval"],
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreSyntheticDocQAGovernmentReportsRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreSyntheticDocQAGovernmentReportsRetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/syntheticDocQA_government_reports_test_beir",
            "revision": "ec534abea699035a18f9fd76f215277de9db9600",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
        adapted_from=["VidoreDocVQARetrieval"],
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True


class VidoreSyntheticDocQAHealthcareIndustryRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="VidoreSyntheticDocQAHealthcareIndustryRetrieval",
        description="Retrieve associated pages according to questions.",
        reference="https://arxiv.org/pdf/2407.01449",
        dataset={
            "path": "mteb/syntheticDocQA_healthcare_industry_test_beir",
            "revision": "81d53880628d641aaf7365f3b2e65f57c814ecca",
        },
        type="DocumentUnderstanding",
        category="t2i",
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_5",
        date=("2024-01-01", "2024-07-01"),
        domains=["Academic"],
        task_subtypes=["Image Text Retrieval"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        modalities=["text", "image"],
        sample_creation="found",
        bibtex_citation=r"""
@article{faysse2024colpali,
  author = {Faysse, Manuel and Sibille, Hugues and Wu, Tony and Viaud, Gautier and Hudelot, C{\'e}line and Colombo, Pierre},
  journal = {arXiv preprint arXiv:2407.01449},
  title = {ColPali: Efficient Document Retrieval with Vision Language Models},
  year = {2024},
}
""",
        prompt={"query": "Find a screenshot that relevant to the user's question."},
        adapted_from=["VidoreDocVQARetrieval"],
    )

    def load_data(self, num_proc: int | None = None, **kwargs) -> None:
        self.corpus, self.queries, self.relevant_docs = _load_data(
            path=self.metadata.dataset["path"],
            splits=self.metadata.eval_splits,
            revision=self.metadata.dataset["revision"],
        )

        self.data_loaded = True



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Protocol, runtime_checkable

if TYPE_CHECKING:
    from pathlib import Path

    from mteb.types import Array


@runtime_checkable
class CacheBackendProtocol(Protocol):
    """Protocol for a vector cache map (used to store text/image embeddings).

    Implementations may back the cache with different storage backends.

    The cache maps an input item (text or image) to its vector embedding,
    identified by a deterministic hash.
    """

    def __init__(self, directory: Path | None = None, **kwargs: Any) -> None:
        """Initialize the cache backend.

        Args:
            directory: Directory path to store cache files.
            **kwargs: Additional backend-specific arguments.
        """

    def add(self, item: list[dict[str, Any]], vectors: Array) -> None:
        """Add a vector to the cache.

        Args:
            item: Input item containing 'text' or 'image'.
            vectors: Embedding vector of shape (dim,) or (1, dim).
        """

    def get_vector(self, item: dict[str, Any]) -> Array | None:
        """Retrieve the cached vector for the given item.

        Args:
            item: Input item.

        Returns:
            Cached vector as np.ndarray, or None if not found.
        """

    def save(self) -> None:
        """Persist cache data to disk (index + metadata)."""

    def load(self) -> None:
        """Load cache from disk (index + metadata)."""

    def close(self) -> None:
        """Release resources or flush data."""

    def __contains__(self, item: dict[str, Any]) -> bool:
        """Check whether the cache contains an item."""



from .beir_fa import (
    ArguAnaFa,
    ArguAnaFaV2,
    ClimateFEVERFa,
    CQADupstackAndroidRetrievalFa,
    CQADupstackEnglishRetrievalFa,
    CQADupstackGamingRetrievalFa,
    CQADupstackGisRetrievalFa,
    CQADupstackMathematicaRetrievalFa,
    CQADupstackPhysicsRetrievalFa,
    CQADupstackProgrammersRetrievalFa,
    CQADupstackStatsRetrievalFa,
    CQADupstackTexRetrievalFa,
    CQADupstackUnixRetrievalFa,
    CQADupstackWebmastersRetrievalFa,
    CQADupstackWordpressRetrievalFa,
    DBPediaFa,
    FEVERFaHardNegatives,
    FiQA2018Fa,
    FiQA2018FaV2,
    HotpotQAFa,
    HotpotQAFaHardNegatives,
    MSMARCOFa,
    MSMARCOFaHardNegatives,
    NFCorpusFa,
    NQFa,
    NQFaHardNegatives,
    QuoraRetrievalFa,
    QuoraRetrievalFaV2,
    SCIDOCSFa,
    SCIDOCSFaV2,
    SciFactFa,
    SciFactFaV2,
    Touche2020Fa,
    Touche2020FaV2,
    TRECCOVIDFa,
    TRECCOVIDFaV2,
)
from .fa_mteb_retrieval import (
    PersianWebDocumentRetrieval,
    SynPerChatbotRAGFAQRetrieval,
    SynPerChatbotRAGTopicsRetrieval,
    SynPerChatbotTopicsRetrieval,
    SynPerQARetrieval,
)

__all__ = [
    "ArguAnaFa",
    "ArguAnaFaV2",
    "CQADupstackAndroidRetrievalFa",
    "CQADupstackEnglishRetrievalFa",
    "CQADupstackGamingRetrievalFa",
    "CQADupstackGisRetrievalFa",
    "CQADupstackMathematicaRetrievalFa",
    "CQADupstackPhysicsRetrievalFa",
    "CQADupstackProgrammersRetrievalFa",
    "CQADupstackStatsRetrievalFa",
    "CQADupstackTexRetrievalFa",
    "CQADupstackUnixRetrievalFa",
    "CQADupstackWebmastersRetrievalFa",
    "CQADupstackWordpressRetrievalFa",
    "ClimateFEVERFa",
    "DBPediaFa",
    "FEVERFaHardNegatives",
    "FiQA2018Fa",
    "FiQA2018FaV2",
    "HotpotQAFa",
    "HotpotQAFaHardNegatives",
    "MSMARCOFa",
    "MSMARCOFaHardNegatives",
    "NFCorpusFa",
    "NQFa",
    "NQFaHardNegatives",
    "PersianWebDocumentRetrieval",
    "QuoraRetrievalFa",
    "QuoraRetrievalFaV2",
    "SCIDOCSFa",
    "SCIDOCSFaV2",
    "SciFactFa",
    "SciFactFaV2",
    "SynPerChatbotRAGFAQRetrieval",
    "SynPerChatbotRAGTopicsRetrieval",
    "SynPerChatbotTopicsRetrieval",
    "SynPerQARetrieval",
    "TRECCOVIDFa",
    "TRECCOVIDFaV2",
    "Touche2020Fa",
    "Touche2020FaV2",
]



from mteb.abstasks.clustering_legacy import AbsTaskClusteringLegacy
from mteb.abstasks.task_metadata import TaskMetadata


class TinyImageNet(AbsTaskClusteringLegacy):
    metadata = TaskMetadata(
        name="TinyImageNetClustering",
        description="Clustering over 200 classes.",
        reference="https://huggingface.co/datasets/zh-plus/tiny-imagenet/viewer/default/valid",
        dataset={
            "path": "mteb/tiny-imagenet",
            "revision": "e04e259f646f750bd0bdb2a56c2a4577d89bee3d",
        },
        type="ImageClustering",
        category="i2c",
        eval_splits=["valid"],
        eval_langs=["eng-Latn"],
        main_score="nmi",
        date=(
            "2012-01-01",
            "2015-12-31",
        ),  # Estimated range for the collection of reviews
        domains=["Reviews"],
        task_subtypes=["Sentiment/Hate speech"],
        license="not specified",
        annotations_creators="derived",
        dialect=[],
        modalities=["image"],
        sample_creation="found",
        bibtex_citation="""""",
    )
    input_column_name = "image"
    label_column_name = "label"



from mteb.abstasks.retrieval import AbsTaskRetrieval
from mteb.abstasks.task_metadata import TaskMetadata


class HiFiTTSA2TRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="HiFiTTSA2TRetrieval",
        description="Sentence-level text captions aligned to 44.1 kHz audiobook speech segments from the Hi‑Fi Multi‑Speaker English TTS dataset. Dataset is based on public audiobooks from LibriVox and texts from Project Gutenberg.",
        reference="https://openslr.org/109/",
        dataset={
            "path": "mteb/hifi-tts_a2t",
            "revision": "4535eb399017ce24ce41cfcdc7c157bf76bcfa27",
        },
        type="Any2AnyRetrieval",
        category="a2t",
        modalities=["text", "audio"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="hit_rate_at_5",
        date=("2021-01-01", "2021-12-31"),
        domains=["Spoken"],
        task_subtypes=["Speech Transcription Retrieval"],
        license="cc-by-4.0",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{bakhturina2021hi,
  author = {Bakhturina, Evelina and Lavrukhin, Vitaly and Ginsburg, Boris and Zhang, Yang},
  journal = {arXiv preprint arXiv:2104.01497},
  title = {{Hi-Fi Multi-Speaker English TTS Dataset}},
  year = {2021},
}
""",
    )


class HiFiTTST2ARetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="HiFiTTST2ARetrieval",
        description="Sentence-level text captions aligned to 44.1 kHz audiobook speech segments from the Hi‑Fi Multi‑Speaker English TTS dataset. Dataset is based on public audiobooks from LibriVox and texts from Project Gutenberg.",
        reference="https://openslr.org/109/",
        dataset={
            "path": "mteb/hifi-tts_t2a",
            "revision": "c5783d12999ec5f6a9f337990cfd46cc131e2b0f",
        },
        type="Any2AnyRetrieval",
        category="t2a",
        modalities=["text", "audio"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="hit_rate_at_5",
        date=("2021-01-01", "2021-12-31"),
        domains=["Spoken"],
        task_subtypes=["Speech Transcription Retrieval"],
        license="cc-by-4.0",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation=r"""
@article{bakhturina2021hi,
  author = {Bakhturina, Evelina and Lavrukhin, Vitaly and Ginsburg, Boris and Zhang, Yang},
  journal = {arXiv preprint arXiv:2104.01497},
  title = {{Hi-Fi Multi-Speaker English TTS Dataset}},
  year = {2021},
}
""",
    )
